'use client';

// src/components/Form/Form.tsx
import { cn as cn36 } from "@paalan/react-shared/lib";

// src/base/Box/Box.tsx
import { StyledComponent, WithStyledComponent } from "@paalan/react-shared/system";
import { forwardRef } from "@paalan/react-shared/utils";
import { jsx } from "react/jsx-runtime";
var Box = forwardRef((props, ref) => {
  return /* @__PURE__ */ jsx(StyledComponent, { ...props, ref });
});
Box.withComponent = WithStyledComponent;

// src/base/Center/Center.tsx
import { cn } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef2 } from "@paalan/react-shared/utils";
import { jsx as jsx2 } from "react/jsx-runtime";
var Center = forwardRef2((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx2(Box, { className: cn("flex items-center justify-center", className), ...restProps, ref, children });
});

// src/base/Container/Container.tsx
import { cn as cn2 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef3 } from "@paalan/react-shared/utils";
import { jsx as jsx3 } from "react/jsx-runtime";
var Container = forwardRef3((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx3(Box, { className: cn2("container", className), ...restProps, ref, children });
});

// src/base/Flex/Flex.tsx
import { cn as cn3 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef4 } from "@paalan/react-shared/utils";
import { jsx as jsx4 } from "react/jsx-runtime";
var Flex = forwardRef4((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx4(Box, { className: cn3("flex", className), ...restProps, ref, children });
});

// src/base/Grid/Grid.tsx
import { cn as cn4 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef5 } from "@paalan/react-shared/utils";
import { jsx as jsx5 } from "react/jsx-runtime";
var Grid = forwardRef5((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx5(Box, { className: cn4("grid", className), ...restProps, ref, children });
});
var GridItem = forwardRef5((props, ref) => {
  const { children, ...restProps } = props;
  return /* @__PURE__ */ jsx5(Box, { ...restProps, ref, children });
});

// src/base/HStack/HStack.tsx
import { cn as cn5 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef6 } from "@paalan/react-shared/utils";
import { jsx as jsx6 } from "react/jsx-runtime";
var HStack = forwardRef6((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx6(Box, { className: cn5("flex flex-row items-center gap-2", className), ...restProps, ref, children });
});

// src/base/Heading/Heading.tsx
import { cn as cn6 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef7 } from "@paalan/react-shared/utils";
import { jsx as jsx7 } from "react/jsx-runtime";
var headingSizes = {
  h1: "text-3xl font-bold",
  h2: "text-2xl font-bold",
  h3: "text-xl font-semibold",
  h4: "text-lg font-semibold",
  h5: "text-base font-semibold",
  h6: "text-sm font-semibold"
};
var Heading = forwardRef7((props, ref) => {
  const { children, as: headTag = "h1", className, ...restProps } = props;
  const size = headingSizes[headTag];
  return /* @__PURE__ */ jsx7(Box, { as: headTag, ...restProps, ref, className: cn6(size, className), children });
});

// src/base/Paper/Paper.tsx
import { cn as cn7 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef8 } from "@paalan/react-shared/utils";
import { cva } from "class-variance-authority";
import { jsx as jsx8 } from "react/jsx-runtime";
var paperVariants = cva("bg-background text-foreground", {
  variants: {
    shadow: {
      default: "shadow",
      sm: "shadow-sm",
      md: "shadow-md",
      lg: "shadow-lg",
      xl: "shadow-xl",
      "2xl": "shadow-2xl",
      inner: "shadow-inner",
      none: "shadow-none"
    }
  },
  defaultVariants: {
    shadow: "default"
  }
});
var Paper = forwardRef8(
  ({ withBorder, shadow, className, ...props }, ref) => {
    return /* @__PURE__ */ jsx8(
      Box,
      {
        ref,
        className: cn7(paperVariants({ shadow }), withBorder ? "border border-border" : "", className),
        ...props
      }
    );
  }
);

// src/base/Portal/Portal.tsx
import { forwardRef as forwardRef9, useRef, useState } from "react";
import { useIsomorphicEffect } from "@paalan/react-hooks";
import { assignRef } from "@paalan/react-shared/utils";
import { createPortal } from "react-dom";
import { Fragment, jsx as jsx9 } from "react/jsx-runtime";
var createPortalNode = (props) => {
  const node = document.createElement("div");
  node.setAttribute("data-portal", "true");
  if (typeof props.className === "string") {
    node.classList.add(...props.className.split(" "));
  }
  if (typeof props.style === "object") {
    Object.assign(node.style, props.style);
  }
  if (typeof props.id === "string") {
    node.setAttribute("id", props.id);
  }
  return node;
};
var defaultProps = {};
var Portal = forwardRef9((props, ref) => {
  const { children, target, ...others } = { ...defaultProps, ...props };
  const [mounted, setMounted] = useState(false);
  const nodeRef = useRef(null);
  useIsomorphicEffect(() => {
    setMounted(true);
    nodeRef.current = !target ? createPortalNode(others) : typeof target === "string" ? document.querySelector(target) : target;
    if (!nodeRef.current) return;
    assignRef(ref, nodeRef.current);
    if (!target && nodeRef.current) {
      document.body.appendChild(nodeRef.current);
    }
    return () => {
      if (!target && nodeRef.current) {
        document.body.removeChild(nodeRef.current);
      }
    };
  }, [target]);
  if (!mounted || !nodeRef.current) {
    return null;
  }
  return createPortal(/* @__PURE__ */ jsx9(Fragment, { children }), nodeRef.current);
});
Portal.displayName = "Portal";

// src/base/Stack/Stack.tsx
import { cn as cn8 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef10 } from "@paalan/react-shared/utils";
import { jsx as jsx10 } from "react/jsx-runtime";
var Stack = forwardRef10((props, ref) => {
  const { children, className, direction, ...restProps } = props;
  return /* @__PURE__ */ jsx10(Box, { className: cn8("flex flex-col gap-2", className), flexDirection: direction, ...restProps, ref, children });
});

// src/base/Text/Text.tsx
import { cn as cn9 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef11 } from "@paalan/react-shared/utils";
import { jsx as jsx11 } from "react/jsx-runtime";
var Text = forwardRef11((props, ref) => {
  const { children, className, as = "p", ...restProps } = props;
  return /* @__PURE__ */ jsx11(Box, { as, ref, className: cn9("", className), ...restProps, children });
});

// src/base/Typography/Typography.tsx
import { cn as cn10 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef12 } from "@paalan/react-shared/utils";
import { jsx as jsx12 } from "react/jsx-runtime";
var H1 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "h1",
    ref,
    className: cn10("scroll-m-20 text-4xl font-extrabold tracking-tight lg:text-5xl", className),
    ...props
  }
));
H1.displayName = "H1";
var H2 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "h2",
    ref,
    className: cn10(
      "mt-10 scroll-m-20 border-b pb-2 text-3xl font-semibold tracking-tight transition-colors first:mt-0",
      className
    ),
    ...props
  }
));
H2.displayName = "H2";
var H3 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "h3",
    ref,
    className: cn10("mt-8 scroll-m-20 text-2xl font-semibold tracking-tight", className),
    ...props
  }
));
H3.displayName = "H3";
var H4 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "h4", ref, className: cn10("scroll-m-20 text-xl font-semibold tracking-tight", className), ...props }));
H4.displayName = "H4";
var H5 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "h5", ref, className: cn10("scroll-m-20 text-lg font-semibold tracking-tight", className), ...props }));
H5.displayName = "H5";
var H6 = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "h6", ref, className: cn10("scroll-m-20 text-base font-semibold tracking-tight", className), ...props }));
H6.displayName = "H6";
var P = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "p", ref, className: cn10("leading-7 [&:not(:first-child)]:mt-4", className), ...props }));
P.displayName = "P";
var BlockQuote = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
    Box,
    {
      as: "blockquote",
      ref,
      className: cn10(
        "mt-6 border-l-2 border-slate-300 pl-6 italic text-slate-800 dark:border-slate-600 dark:text-slate-200",
        className
      ),
      ...props
    }
  )
);
BlockQuote.displayName = "BlockQuote";
var TableLayout = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "table", ref, className: cn10("w-full", className), ...props })
);
TableLayout.displayName = "Table";
var THead = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "thead", ref, className: cn10("", className), ...props })
);
THead.displayName = "THead";
var TBody = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "tbody", ref, className: cn10("", className), ...props })
);
TBody.displayName = "TBody";
var TR = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "tr",
    ref,
    className: cn10(
      "m-0 border-t border-slate-300 p-0 even:bg-slate-100 dark:border-slate-700 dark:even:bg-slate-800",
      className
    ),
    ...props
  }
));
TR.displayName = "TR";
var TD = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "td",
    ref,
    className: cn10(
      "border border-slate-200 px-4 py-2 text-left dark:border-slate-700 [&[align=center]]:text-center [&[align=right]]:text-right",
      className
    ),
    ...props
  }
));
TD.displayName = "TD";
var TH = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "th",
    ref,
    className: cn10(
      "border border-slate-200 px-4 py-2 text-left font-bold dark:border-slate-700 [&[align=center]]:text-center [&[align=right]]:text-right",
      className
    ),
    ...props
  }
));
TH.displayName = "TH";
var UL = forwardRef12(({ className, unstyled = false, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "ul",
    ref,
    className: cn10(
      {
        "m-4 list-disc [&>li]:mt-2": !unstyled
      },
      className
    ),
    ...props
  }
));
UL.displayName = "UL";
var OL = forwardRef12(({ className, unstyled = false, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "ol",
    ref,
    className: cn10(
      {
        "m-4 list-decimal [&>li]:mt-2": !unstyled
      },
      className
    ),
    ...props
  }
));
OL.displayName = "OL";
var LI = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "li", ref, className: cn10("", className), ...props }));
LI.displayName = "LI";
var Code = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(
  Box,
  {
    as: "code",
    ref,
    className: cn10("relative rounded bg-muted px-[0.3rem] py-[0.2rem] font-mono text-sm font-normal", className),
    ...props
  }
));
Code.displayName = "Code";
var Lead = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "p", ref, className: cn10("text-xl text-muted-foreground", className), ...props }));
Lead.displayName = "Lead";
var Large = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "div", ref, className: cn10("text-lg font-semibold", className), ...props }));
Large.displayName = "Large";
var Small = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "small", ref, className: cn10("text-sm font-medium leading-none", className), ...props })
);
Small.displayName = "Small";
var Subtle = forwardRef12(({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "p", ref, className: cn10("text-sm text-muted-foreground", className), ...props }));
Subtle.displayName = "Subtle";
var Strong = forwardRef12(
  ({ className, ...props }, ref) => /* @__PURE__ */ jsx12(Box, { as: "strong", ref, className: cn10("font-semibold", className), ...props })
);
Strong.displayName = "Strong";

// src/base/VStack/VStack.tsx
import { cn as cn11 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef13 } from "@paalan/react-shared/utils";
import { jsx as jsx13 } from "react/jsx-runtime";
var VStack = forwardRef13((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx13(Box, { className: cn11("flex flex-col items-stretch gap-2", className), ...restProps, ref, children });
});

// src/base/Wrap/Wrap.tsx
import { cn as cn12 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef14 } from "@paalan/react-shared/utils";
import { jsx as jsx14 } from "react/jsx-runtime";
var Wrap = forwardRef14((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx14(Box, { className: cn12("flex flex-wrap gap-2", className), ...restProps, ref, children });
});
var WrapItem = forwardRef14((props, ref) => {
  const { children, className, ...restProps } = props;
  return /* @__PURE__ */ jsx14(Box, { className: cn12("flex flex-none items-start", className), ...restProps, ref, children });
});

// src/components/Button/Button.tsx
import { ArrowPathIcon } from "@paalan/react-icons";
import { cn as cn13 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef15 } from "@paalan/react-shared/utils";
import { Slot } from "@radix-ui/react-slot";
import { cva as cva2 } from "class-variance-authority";

// src/components/Button/constants.ts
var LOADING_ICON_SIZE = {
  xs: "w-3 h-3",
  sm: "w-4 h-4",
  md: "w-5 h-5",
  lg: "w-6 h-6",
  xl: "w-7 h-7"
};
var BUTTON_SIZE = {
  xs: "px-2 py-1 text-xs",
  sm: "px-3 py-1 text-sm",
  md: "px-4 py-2 text-sm",
  lg: "px-6 py-2 text-base",
  xl: "px-8 py-2.5 text-base"
};
var BUTTON_ROUNDED = {
  none: "rounded-none",
  sm: "rounded-sm",
  md: "rounded-md",
  lg: "rounded-lg",
  xl: "rounded-xl",
  "2xl": "rounded-2xl",
  "3xl": "rounded-3xl",
  full: "rounded-full"
};
var BUTTON_COLOR_VARIANT_MAPPING = {
  solid: {
    gray: "bg-gray-600 hover:bg-gray-700 focus-visible:ring-gray-500 text-gray-50",
    red: "bg-red-600 hover:bg-red-700 focus-visible:ring-red-500 text-red-50",
    orange: "bg-orange-600 hover:bg-orange-700 focus-visible:ring-orange-500 text-orange-50",
    amber: "bg-amber-600 hover:bg-amber-700 focus-visible:ring-amber-500 text-amber-50",
    yellow: "bg-yellow-600 hover:bg-yellow-700 focus-visible:ring-yellow-500 text-yellow-50",
    lime: "bg-lime-600 hover:bg-lime-700 focus-visible:ring-lime-500 text-lime-50",
    green: "bg-green-600 hover:bg-green-700 focus-visible:ring-green-500 text-green-50",
    emerald: "bg-emerald-600 hover:bg-emerald-700 focus-visible:ring-emerald-500 text-emerald-50",
    teal: "bg-teal-600 hover:bg-teal-700 focus-visible:ring-teal-500 text-teal-50",
    cyan: "bg-cyan-600 hover:bg-cyan-700 focus-visible:ring-cyan-500 text-cyan-50",
    sky: "bg-sky-600 hover:bg-sky-700 focus-visible:ring-sky-500 text-sky-50",
    blue: "bg-blue-600 hover:bg-blue-700 focus-visible:ring-blue-500 text-blue-50",
    indigo: "bg-indigo-600 hover:bg-indigo-700 focus-visible:ring-indigo-500 text-indigo-50",
    violet: "bg-violet-600 hover:bg-violet-700 focus-visible:ring-violet-500 text-violet-50",
    purple: "bg-purple-600 hover:bg-purple-700 focus-visible:ring-purple-500 text-purple-50",
    fuchsia: "bg-fuchsia-600 hover:bg-fuchsia-700 focus-visible:ring-fuchsia-500 text-fuchsia-50",
    pink: "bg-pink-600 hover:bg-pink-700 focus-visible:ring-pink-500 text-pink-50",
    rose: "bg-rose-600 hover:bg-rose-700 focus-visible:ring-rose-500 text-rose-50",
    primary: "bg-primary hover:bg-primary/90 focus-visible:ring-primary text-primary-foreground",
    secondary: "bg-secondary hover:bg-secondary/90 focus-visible:ring-secondary text-secondary-foreground",
    tertiary: "bg-tertiary hover:bg-tertiary/90 focus-visible:ring-tertiary text-tertiary-foreground",
    info: "bg-info hover:bg-info/90 focus-visible:ring-info text-info-foreground",
    danger: "bg-danger hover:bg-danger/90 focus-visible:ring-danger text-danger-foreground",
    success: "bg-success hover:bg-success/90 focus-visible:ring-success text-success-foreground",
    warning: "bg-warning hover:bg-warning/90 focus-visible:ring-warning text-warning-foreground"
  },
  surface: {
    gray: "bg-transparent text-gray-600 hover:bg-gray-50 focus:ring-gray-200 focus-visible:ring-gray-500 border border-current",
    red: "bg-transparent text-red-600 hover:bg-red-50 focus:ring-red-200 focus-visible:ring-red-500 border border-current",
    orange: "bg-transparent text-orange-600 hover:bg-orange-50 focus:ring-orange-200 focus-visible:ring-orange-500 border border-current",
    amber: "bg-transparent text-amber-600 hover:bg-amber-50 focus:ring-amber-200 focus-visible:ring-amber-500 border border-current",
    yellow: "bg-transparent text-yellow-600 hover:bg-yellow-50 focus:ring-yellow-200 focus-visible:ring-yellow-500 border border-current",
    lime: "bg-transparent text-lime-600 hover:bg-lime-50 focus:ring-lime-200 focus-visible:ring-lime-500 border border-current",
    green: "bg-transparent text-green-600 hover:bg-green-50 focus:ring-green-200 focus-visible:ring-green-500 border border-current",
    emerald: "bg-transparent text-emerald-600 hover:bg-emerald-50 focus:ring-emerald-200 focus-visible:ring-emerald-500 border border-current",
    teal: "bg-transparent text-teal-600 hover:bg-teal-50 focus:ring-teal-200 focus-visible:ring-teal-500 border border-current",
    cyan: "bg-transparent text-cyan-600 hover:bg-cyan-50 focus:ring-cyan-200 focus-visible:ring-cyan-500 border border-current",
    sky: "bg-transparent text-sky-600 hover:bg-sky-50 focus:ring-sky-200 focus-visible:ring-sky-500 border border-current",
    blue: "bg-transparent text-blue-600 hover:bg-blue-50 focus:ring-blue-200 focus-visible:ring-blue-500 border border-current",
    indigo: "bg-transparent text-indigo-600 hover:bg-indigo-50 focus:ring-indigo-200 focus-visible:ring-indigo-500 border border-current",
    violet: "bg-transparent text-violet-600 hover:bg-violet-50 focus:ring-violet-200 focus-visible:ring-violet-500 border border-current",
    purple: "bg-transparent text-purple-600 hover:bg-purple-50 focus:ring-purple-200 focus-visible:ring-purple-500 border border-current",
    fuchsia: "bg-transparent text-fuchsia-600 hover:bg-fuchsia-50 focus:ring-fuchsia-200 focus-visible:ring-fuchsia-500 border border-current",
    pink: "bg-transparent text-pink-600 hover:bg-pink-50 focus:ring-pink-200 focus-visible:ring-pink-500 border border-current",
    rose: "bg-transparent text-rose-600 hover:bg-rose-50 focus:ring-rose-200 focus-visible:ring-rose-500 border border-current",
    primary: "bg-transparent text-primary hover:bg-primary/10 focus:ring-primary focus-visible:ring-primary border border-current",
    secondary: "bg-transparent text-secondary-foreground/90 hover:bg-secondary-foreground/10 focus:ring-secondary-foreground focus-visible:ring-secondary-foreground border border-current",
    tertiary: "bg-transparent text-tertiary hover:bg-tertiary/10 focus:ring-tertiary focus-visible:ring-tertiary border border-current",
    info: "bg-transparent text-info hover:bg-info/10 focus:ring-info focus-visible:ring-info border border-current",
    danger: "bg-transparent text-danger hover:bg-danger/10 focus:ring-danger focus-visible:ring-danger border border-current",
    success: "bg-transparent text-success hover:bg-success/10 focus:ring-success focus-visible:ring-success border border-current",
    warning: "bg-transparent text-warning hover:bg-warning/10 focus:ring-warning focus-visible:ring-warning border border-current"
  },
  outline: {
    gray: "bg-transparent text-gray-600 hover:bg-gray-600 hover:text-gray-50 focus-visible:ring-gray-500 border border-current hover:border-gray-600",
    red: "bg-transparent text-red-600 hover:bg-red-600 hover:text-red-50 focus-visible:ring-red-500 border border-current hover:border-red-600",
    orange: "bg-transparent text-orange-600 hover:bg-orange-600 hover:text-orange-50 focus-visible:ring-orange-500 border border-current hover:border-orange-600",
    amber: "bg-transparent text-amber-600 hover:bg-amber-600 hover:text-amber-50 focus-visible:ring-amber-500 border border-current hover:border-amber-600",
    yellow: "bg-transparent text-yellow-600 hover:bg-yellow-600 hover:text-yellow-50 focus-visible:ring-yellow-500 border border-current hover:border-yellow-600",
    lime: "bg-transparent text-lime-600 hover:bg-lime-600 hover:text-lime-50 focus-visible:ring-lime-500 border border-current hover:border-lime-600",
    green: "bg-transparent text-green-600 hover:bg-green-600 hover:text-green-50 focus-visible:ring-green-500 border border-current hover:border-green-600",
    emerald: "bg-transparent text-emerald-600 hover:bg-emerald-600 hover:text-emerald-50 focus-visible:ring-emerald-500 border border-current hover:border-emerald-600",
    teal: "bg-transparent text-teal-600 hover:bg-teal-600 hover:text-teal-50 focus-visible:ring-teal-500 border border-current hover:border-teal-600",
    cyan: "bg-transparent text-cyan-600 hover:bg-cyan-600 hover:text-cyan-50 focus-visible:ring-cyan-500 border border-current hover:border-cyan-600",
    sky: "bg-transparent text-sky-600 hover:bg-sky-600 hover:text-sky-50 focus-visible:ring-sky-500 border border-current hover:border-sky-600",
    blue: "bg-transparent text-blue-600 hover:bg-blue-600 hover:text-blue-50 focus-visible:ring-blue-500 border border-current hover:border-blue-600",
    indigo: "bg-transparent text-indigo-600 hover:bg-indigo-600 hover:text-indigo-50 focus-visible:ring-indigo-500 border border-current hover:border-indigo-600",
    violet: "bg-transparent text-violet-600 hover:bg-violet-600 hover:text-violet-50 focus-visible:ring-violet-500 border border-current hover:border-violet-600",
    purple: "bg-transparent text-purple-600 hover:bg-purple-600 hover:text-purple-50 focus-visible:ring-purple-500 border border-current hover:border-purple-600",
    fuchsia: "bg-transparent text-fuchsia-600 hover:bg-fuchsia-600 hover:text-fuchsia-50 focus-visible:ring-fuchsia-500 border border-current hover:border-fuchsia-600",
    pink: "bg-transparent text-pink-600 hover:bg-pink-600 hover:text-pink-50 focus-visible:ring-pink-500 border border-current hover:border-pink-600",
    rose: "bg-transparent text-rose-600 hover:bg-rose-600 hover:text-rose-50 focus-visible:ring-rose-500 border border-current hover:border-rose-600",
    primary: "bg-transparent text-primary hover:bg-primary hover:text-primary-foreground focus-visible:ring-primary border border-current hover:border-primary",
    secondary: "bg-transparent text-secondary-foreground hover:bg-secondary-foreground/80 hover:text-secondary focus-visible:ring-secondary-foreground border border-current hover:border-secondary",
    tertiary: "bg-transparent text-tertiary hover:bg-tertiary hover:text-tertiary-foreground focus-visible:ring-tertiary border border-current hover:border-tertiary",
    info: "bg-transparent text-info hover:bg-info hover:text-info-foreground focus-visible:ring-info border border-current hover:border-info",
    danger: "bg-transparent text-danger hover:bg-danger hover:text-danger-foreground focus-visible:ring-danger border border-current hover:border-danger",
    success: "bg-transparent text-success hover:bg-success hover:text-success-foreground focus-visible:ring-success border border-current hover:border-success",
    warning: "bg-transparent text-warning hover:bg-warning hover:text-warning-foreground focus-visible:ring-warning border border-current hover:border-warning"
  },
  soft: {
    gray: "bg-gray-100 hover:bg-gray-200 text-gray-800 focus-visible:ring-gray-600",
    red: "bg-red-100 hover:bg-red-200 text-red-800 focus-visible:ring-red-600",
    orange: "bg-orange-100 hover:bg-orange-200 text-orange-800 focus-visible:ring-orange-600",
    amber: "bg-amber-100 hover:bg-amber-200 text-amber-800 focus-visible:ring-amber-600",
    yellow: "bg-yellow-100 hover:bg-yellow-200 text-yellow-800 focus-visible:ring-yellow-600",
    lime: "bg-lime-100 hover:bg-lime-200 text-lime-800 focus-visible:ring-lime-600",
    green: "bg-green-100 hover:bg-green-200 text-green-800 focus-visible:ring-green-600",
    emerald: "bg-emerald-100 hover:bg-emerald-200 text-emerald-800 focus-visible:ring-emerald-600",
    teal: "bg-teal-100 hover:bg-teal-200 text-teal-800 focus-visible:ring-teal-600",
    cyan: "bg-cyan-100 hover:bg-cyan-200 text-cyan-800 focus-visible:ring-cyan-600",
    sky: "bg-sky-100 hover:bg-sky-200 text-sky-800 focus-visible:ring-sky-600",
    blue: "bg-blue-100 hover:bg-blue-200 text-blue-800 focus-visible:ring-blue-600",
    indigo: "bg-indigo-100 hover:bg-indigo-200 text-indigo-800 focus-visible:ring-indigo-600",
    violet: "bg-violet-100 hover:bg-violet-200 text-violet-800 focus-visible:ring-violet-600",
    purple: "bg-purple-100 hover:bg-purple-200 text-purple-800 focus-visible:ring-purple-600",
    fuchsia: "bg-fuchsia-100 hover:bg-fuchsia-200 text-fuchsia-800 focus-visible:ring-fuchsia-600",
    pink: "bg-pink-100 hover:bg-pink-200 text-pink-800 focus-visible:ring-pink-600",
    rose: "bg-rose-100 hover:bg-rose-200 text-rose-800 focus-visible:ring-rose-600",
    primary: "bg-primary-soft hover:bg-primary-soft/90 text-primary/90 focus-visible:ring-primary",
    secondary: "bg-secondary-soft hover:bg-secondary-soft/90 text-secondary-foreground/70 focus-visible:ring-secondary-foreground",
    tertiary: "bg-tertiary-soft hover:bg-tertiary-soft/90 text-tertiary/90 focus-visible:ring-tertiary",
    info: "bg-info-soft hover:bg-info-soft/90 text-info/90 focus-visible:ring-info",
    danger: "bg-danger-soft hover:bg-danger-soft/90 text-danger/90 focus-visible:ring-danger",
    success: "bg-success-soft hover:bg-success-soft/90 text-success/90 focus-visible:ring-success",
    warning: "bg-warning-soft hover:bg-warning-soft/90 text-warning focus-visible:ring-warning"
  },
  ghost: {
    gray: "bg-transparent text-gray-600 hover:bg-gray-50 shadow-none focus-visible:ring-gray-500",
    red: "bg-transparent text-red-600 hover:bg-red-50 shadow-none focus-visible:ring-red-500",
    orange: "bg-transparent text-orange-600 hover:bg-orange-50 shadow-none focus-visible:ring-orange-500",
    amber: "bg-transparent text-amber-600 hover:bg-amber-50 shadow-none focus-visible:ring-amber-500",
    yellow: "bg-transparent text-yellow-600 hover:bg-yellow-50 shadow-none focus-visible:ring-yellow-500",
    lime: "bg-transparent text-lime-600 hover:bg-lime-50 shadow-none focus-visible:ring-lime-500",
    green: "bg-transparent text-green-600 hover:bg-green-50 shadow-none focus-visible:ring-green-500",
    emerald: "bg-transparent text-emerald-600 hover:bg-emerald-50 shadow-none focus-visible:ring-emerald-500",
    teal: "bg-transparent text-teal-600 hover:bg-teal-50 shadow-none focus-visible:ring-teal-500",
    cyan: "bg-transparent text-cyan-600 hover:bg-cyan-50 shadow-none focus-visible:ring-cyan-500",
    sky: "bg-transparent text-sky-600 hover:bg-sky-50 shadow-none focus-visible:ring-sky-500",
    blue: "bg-transparent text-blue-600 hover:bg-blue-50 shadow-none focus-visible:ring-blue-500",
    indigo: "bg-transparent text-indigo-600 hover:bg-indigo-50 shadow-none focus-visible:ring-indigo-500",
    violet: "bg-transparent text-violet-600 hover:bg-violet-50 shadow-none focus-visible:ring-violet-500",
    purple: "bg-transparent text-purple-600 hover:bg-purple-50 shadow-none focus-visible:ring-purple-500",
    fuchsia: "bg-transparent text-fuchsia-600 hover:bg-fuchsia-50 shadow-none focus-visible:ring-fuchsia-500",
    pink: "bg-transparent text-pink-600 hover:bg-pink-50 shadow-none focus-visible:ring-pink-500",
    rose: "bg-transparent text-rose-600 hover:bg-rose-50 shadow-none focus-visible:ring-rose-500",
    primary: "bg-transparent text-primary hover:bg-primary/10 shadow-none focus-visible:ring-primary",
    secondary: "bg-transparent text-secondary-foreground/90 hover:bg-secondary-foreground/10 shadow-none focus-visible:ring-secondary-foreground",
    tertiary: "bg-transparent text-tertiary hover:bg-tertiary/10 shadow-none focus-visible:ring-tertiary",
    info: "bg-transparent text-info hover:bg-info/10 shadow-none focus-visible:ring-info",
    danger: "bg-transparent text-danger hover:bg-danger/10 shadow-none focus-visible:ring-danger",
    success: "bg-transparent text-success hover:bg-success/10 shadow-none focus-visible:ring-success",
    warning: "bg-transparent text-warning hover:bg-warning/10 shadow-none focus-visible:ring-warning"
  },
  link: {
    gray: "bg-transparent text-gray-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    red: "bg-transparent text-red-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    orange: "bg-transparent text-orange-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    amber: "bg-transparent text-amber-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    yellow: "bg-transparent text-yellow-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    lime: "bg-transparent text-lime-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    green: "bg-transparent text-green-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    emerald: "bg-transparent text-emerald-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    teal: "bg-transparent text-teal-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    cyan: "bg-transparent text-cyan-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    sky: "bg-transparent text-sky-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    blue: "bg-transparent text-blue-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    indigo: "bg-transparent text-indigo-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    violet: "bg-transparent text-violet-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    purple: "bg-transparent text-purple-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    fuchsia: "bg-transparent text-fuchsia-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    pink: "bg-transparent text-pink-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    rose: "bg-transparent text-rose-600 p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    primary: "bg-transparent text-primary p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    secondary: "bg-transparent text-secondary-foreground p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    tertiary: "bg-transparent text-tertiary p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    info: "bg-transparent text-info p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    danger: "bg-transparent text-danger p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    success: "bg-transparent text-success p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent",
    warning: "bg-transparent text-warning p-0 hover:bg-transparent underline-offset-4 hover:underline shadow-none focus-visible:ring-transparent"
  }
};

// src/components/Button/Button.tsx
import { jsx as jsx15, jsxs } from "react/jsx-runtime";
var buttonVariants = cva2(
  "inline-flex items-center justify-center text-sm font-medium transition-colors focus-visible:outline-none focus-visible:ring-2 disabled:pointer-events-none disabled:opacity-50",
  {
    variants: {
      variant: {
        default: BUTTON_COLOR_VARIANT_MAPPING["solid"]["primary"],
        primary: BUTTON_COLOR_VARIANT_MAPPING["solid"]["primary"],
        secondary: BUTTON_COLOR_VARIANT_MAPPING["solid"]["secondary"],
        info: BUTTON_COLOR_VARIANT_MAPPING["solid"]["info"],
        success: BUTTON_COLOR_VARIANT_MAPPING["solid"]["success"],
        warning: BUTTON_COLOR_VARIANT_MAPPING["solid"]["warning"],
        danger: BUTTON_COLOR_VARIANT_MAPPING["solid"]["danger"],
        outline: "border border-input bg-background shadow-sm hover:bg-accent hover:text-accent-foreground",
        ghost: "hover:bg-accent hover:text-accent-foreground"
      },
      rounded: BUTTON_ROUNDED,
      size: BUTTON_SIZE
    },
    defaultVariants: {
      rounded: "md",
      size: "md"
    }
  }
);
var Button = forwardRef15(
  ({
    as: Component = "button",
    className,
    variant = "solid",
    color,
    size,
    label,
    rounded,
    children,
    leftIcon,
    rightIcon,
    asChild = false,
    isLoading,
    loadingText,
    wrapperClassName,
    unstyled,
    disabled,
    ...props
  }, ref) => {
    const Comp = asChild ? Slot : Component;
    let buttonClassName = "";
    if (["outline", "ghost"].includes(variant) && !color) {
      buttonClassName = buttonVariants({
        variant,
        size,
        rounded
      });
    } else {
      buttonClassName = BUTTON_COLOR_VARIANT_MAPPING[variant][color || "primary"];
    }
    return /* @__PURE__ */ jsx15(
      Box,
      {
        ...props,
        as: Comp,
        className: unstyled ? className : cn13(buttonClassName, buttonVariants({ size, rounded }), className),
        ref,
        disabled: isLoading || disabled,
        children: asChild ? children : /* @__PURE__ */ jsxs(Box, { className: cn13("inline-flex flex-1 items-center justify-center gap-1.5", wrapperClassName), children: [
          !isLoading && leftIcon,
          isLoading && /* @__PURE__ */ jsx15(ArrowPathIcon, { className: cn13("size-4 animate-spin", size && LOADING_ICON_SIZE[size]) }),
          isLoading && loadingText ? loadingText : label || children,
          !isLoading && rightIcon
        ] })
      }
    );
  }
);
Button.displayName = "Button";

// src/components/Form/components/index.tsx
import * as React3 from "react";
import { cn as cn16 } from "@paalan/react-shared/lib";
import { Slot as Slot2 } from "@radix-ui/react-slot";
import { Controller, FormProvider, useFormContext } from "react-hook-form";

// src/components/Label/Label.tsx
import * as React2 from "react";
import { InfoOutlineIcon } from "@paalan/react-icons";
import { cn as cn15 } from "@paalan/react-shared/lib";
import * as LabelPrimitive from "@radix-ui/react-label";
import { cva as cva3 } from "class-variance-authority";

// src/components/Tooltip/Tooltip.tsx
import * as React from "react";
import { useControllableState } from "@paalan/react-hooks";
import { cn as cn14 } from "@paalan/react-shared/lib";
import * as TooltipPrimitive from "@radix-ui/react-tooltip";
import { jsx as jsx16, jsxs as jsxs2 } from "react/jsx-runtime";
var TooltipProvider = TooltipPrimitive.Provider;
var TooltipRoot = TooltipPrimitive.Root;
var TooltipTrigger = TooltipPrimitive.Trigger;
var TooltipPortal = TooltipPrimitive.Portal;
var TooltipContent = React.forwardRef(({ className, sideOffset = 4, ...props }, ref) => /* @__PURE__ */ jsx16(
  TooltipPrimitive.Content,
  {
    ref,
    sideOffset,
    className: cn14(
      "z-50 overflow-hidden rounded-md bg-primary px-3 py-1.5 text-xs text-primary-foreground animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      className
    ),
    ...props
  }
));
TooltipContent.displayName = TooltipPrimitive.Content.displayName;
var Tooltip = React.forwardRef(
  ({
    className,
    trigger,
    asPortal,
    content,
    side = "top",
    align = "center",
    defaultOpen,
    open,
    onOpenChange,
    ...props
  }, ref) => {
    const TooltipPortalComponent = asPortal ? TooltipPortal : React.Fragment;
    const [localOpen, setLocalOpen] = useControllableState({
      defaultValue: defaultOpen,
      value: open,
      onChange: onOpenChange
    });
    return /* @__PURE__ */ jsx16(TooltipProvider, { delayDuration: 100, children: /* @__PURE__ */ jsxs2(TooltipRoot, { open: localOpen, onOpenChange: setLocalOpen, children: [
      /* @__PURE__ */ jsx16(TooltipTrigger, { asChild: true, children: trigger }),
      /* @__PURE__ */ jsx16(TooltipPortalComponent, { children: /* @__PURE__ */ jsxs2(
        TooltipContent,
        {
          ref,
          className: cn14("bg-secondary fill-secondary text-secondary-foreground", className),
          side,
          align,
          ...props,
          children: [
            content,
            /* @__PURE__ */ jsx16(TooltipPrimitive.Arrow, { width: 11, height: 5 })
          ]
        }
      ) })
    ] }) });
  }
);

// src/components/Label/Label.tsx
import { jsx as jsx17, jsxs as jsxs3 } from "react/jsx-runtime";
var labelVariants = cva3("text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70");
var Label = React2.forwardRef(
  ({ className, required = false, labelDescription, text, isInvalid, children, disabled, ...props }, ref) => /* @__PURE__ */ jsxs3(
    LabelPrimitive.Root,
    {
      ref,
      className: cn15(labelVariants(), { "text-danger": isInvalid, "opacity-70": disabled }, className),
      ...props,
      children: [
        text || children,
        required && /* @__PURE__ */ jsx17("span", { className: "text-danger/70", children: "*" }),
        labelDescription && /* @__PURE__ */ jsx17(
          Tooltip,
          {
            trigger: /* @__PURE__ */ jsx17(InfoOutlineIcon, { className: "ml-1 text-muted-foreground", "aria-hidden": "true" }),
            content: labelDescription
          }
        )
      ]
    }
  )
);
Label.displayName = LabelPrimitive.Root.displayName;

// src/components/Form/components/index.tsx
import { jsx as jsx18 } from "react/jsx-runtime";
var FormRoot = FormProvider;
var FormFieldContext = React3.createContext({});
var FormField = ({
  ...props
}) => {
  return /* @__PURE__ */ jsx18(FormFieldContext.Provider, { value: { name: props.name }, children: /* @__PURE__ */ jsx18(Controller, { ...props }) });
};
var useFormField = () => {
  const fieldContext = React3.useContext(FormFieldContext);
  const itemContext = React3.useContext(FormItemContext);
  const { getFieldState, formState } = useFormContext();
  const fieldState = getFieldState(fieldContext.name, formState);
  if (!fieldContext) {
    throw new Error("useFormField should be used within <FormField>");
  }
  const { id } = itemContext;
  return {
    id,
    name: fieldContext.name,
    formItemId: `${id}-form-item`,
    formDescriptionId: `${id}-form-item-description`,
    formMessageId: `${id}-form-item-message`,
    ...fieldState
  };
};
var FormItemContext = React3.createContext({});
var FormItem = React3.forwardRef(
  ({ className, ...props }, ref) => {
    const id = React3.useId();
    return /* @__PURE__ */ jsx18(FormItemContext.Provider, { value: { id }, children: /* @__PURE__ */ jsx18("div", { ref, className: cn16("space-y-2", className), ...props }) });
  }
);
FormItem.displayName = "FormItem";
var FormLabel = React3.forwardRef(
  ({ className, required, ...props }, ref) => {
    const { error, formItemId } = useFormField();
    return /* @__PURE__ */ jsx18(
      Label,
      {
        ref,
        className: cn16(error && "text-danger", className),
        htmlFor: formItemId,
        required,
        ...props,
        children: props.children
      }
    );
  }
);
FormLabel.displayName = "FormLabel";
var FormControl = React3.forwardRef(
  ({ ...props }, ref) => {
    const { error, formItemId, formDescriptionId, formMessageId } = useFormField();
    return /* @__PURE__ */ jsx18(
      Slot2,
      {
        ref,
        id: formItemId,
        "aria-describedby": !error ? `${formDescriptionId}` : `${formDescriptionId} ${formMessageId}`,
        "aria-invalid": !!error,
        ...props
      }
    );
  }
);
FormControl.displayName = "FormControl";
var FormDescription = React3.forwardRef(
  ({ className, ...props }, ref) => {
    const { formDescriptionId } = useFormField();
    return /* @__PURE__ */ jsx18("p", { ref, id: formDescriptionId, className: cn16("text-[0.8rem] text-muted-foreground", className), ...props });
  }
);
FormDescription.displayName = "FormDescription";
var FormMessage = React3.forwardRef(
  ({ className, children, ...props }, ref) => {
    const { error, formMessageId } = useFormField();
    const body = error ? String(error?.message) : children;
    if (!body) {
      return null;
    }
    return /* @__PURE__ */ jsx18("p", { ref, id: formMessageId, className: cn16("text-[0.8rem] font-medium text-danger", className), ...props, children: body });
  }
);
FormMessage.displayName = "FormMessage";

// src/components/Form/FormFieldItem/index.tsx
import { cn as cn35 } from "@paalan/react-shared/lib";

// src/components/Checkbox/Checkbox.tsx
import * as React4 from "react";
import { CheckIcon, MinusIcon } from "@paalan/react-icons";
import { cn as cn18, isAriaInvalid } from "@paalan/react-shared/lib";
import * as CheckboxPrimitive from "@radix-ui/react-checkbox";
import { cva as cva4 } from "class-variance-authority";

// src/components/ErrorMessage/ErrorMessage.tsx
import { cn as cn17 } from "@paalan/react-shared/lib";
import { jsx as jsx19 } from "react/jsx-runtime";
var ErrorMessage = ({ message, className, label, ...props }) => {
  const errorMessage = message || (label ? `${label} is required` : "");
  if (!errorMessage) return null;
  return /* @__PURE__ */ jsx19(Text, { className: cn17("mt-2 text-sm text-danger", className), ...props, children: errorMessage });
};

// src/components/Checkbox/Checkbox.tsx
import { Fragment as Fragment3, jsx as jsx20, jsxs as jsxs4 } from "react/jsx-runtime";
var checkboxVariants = cva4(
  "peer size-4 shrink-0 rounded-sm border border-gray-400 focus-visible:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",
  {
    variants: {
      variant: {
        primary: "data-[state=checked]:border-primary data-[state=checked]:bg-primary data-[state=checked]:text-primary-foreground",
        secondary: "data-[state=checked]:border-secondary data-[state=checked]:bg-secondary data-[state=checked]:text-secondary-foreground",
        tertiary: "data-[state=checked]:border-tertiary data-[state=checked]:bg-tertiary data-[state=checked]:text-tertiary-foreground",
        info: "data-[state=checked]:border-info data-[state=checked]:bg-info data-[state=checked]:text-info-foreground",
        success: "data-[state=checked]:border-success data-[state=checked]:bg-success data-[state=checked]:text-success-foreground",
        warning: "data-[state=checked]:border-warning data-[state=checked]:bg-warning data-[state=checked]:text-warning-foreground",
        danger: "data-[state=checked]:border-danger data-[state=checked]:bg-danger data-[state=checked]:text-danger-foreground",
        accent: "data-[state=checked]:border-accent data-[state=checked]:bg-accent data-[state=checked]:text-accent-foreground"
      }
    },
    defaultVariants: {
      variant: "primary"
    }
  }
);
var CheckboxRoot = React4.forwardRef(({ className, variant, indeterminate, ...props }, ref) => /* @__PURE__ */ jsx20(CheckboxPrimitive.Root, { ref, className: cn18(checkboxVariants({ variant }), className), ...props, children: /* @__PURE__ */ jsx20(CheckboxPrimitive.Indicator, { className: cn18("flex items-center justify-center text-current"), children: indeterminate ? /* @__PURE__ */ jsx20(MinusIcon, { className: "size-full pb-0.5" }) : /* @__PURE__ */ jsx20(CheckIcon, { className: "size-[15px]" }) }) }));
CheckboxRoot.displayName = CheckboxPrimitive.Root.displayName;
var Checkbox = React4.forwardRef(
  ({
    label,
    className,
    rootClassName,
    swapRight,
    labelClassName,
    isInvalid: invalid,
    errorMessage,
    indeterminate,
    checked,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid(props["aria-invalid"]) || invalid;
    const id = props.id || props.name || label?.toString() || "";
    const localChecked = checked ?? `${props.value}` === "true";
    return /* @__PURE__ */ jsxs4(Fragment3, { children: [
      /* @__PURE__ */ jsxs4(Box, { className: cn18("flex items-center gap-2", rootClassName), children: [
        /* @__PURE__ */ jsx20(
          CheckboxRoot,
          {
            ref,
            ...props,
            id,
            checked: indeterminate ? true : localChecked,
            indeterminate,
            className: cn18(
              {
                "order-1": swapRight,
                "border-danger data-[state=checked]:bg-danger data-[state=checked]:text-danger-foreground": isInvalid
              },
              className
            )
          }
        ),
        label && /* @__PURE__ */ jsx20(
          Label,
          {
            htmlFor: id,
            text: label,
            required: props.required,
            isInvalid,
            className: cn18("cursor-pointer", labelClassName)
          }
        )
      ] }),
      isInvalid && /* @__PURE__ */ jsx20(ErrorMessage, { message: errorMessage })
    ] });
  }
);
Checkbox.displayName = "Checkbox";

// src/components/CheckboxGroup/CheckboxGroup.tsx
import React5 from "react";
import { cn as cn19, isAriaInvalid as isAriaInvalid2 } from "@paalan/react-shared/lib";
import { Fragment as Fragment4, jsx as jsx21, jsxs as jsxs5 } from "react/jsx-runtime";
var CheckboxGroup = React5.forwardRef(
  ({
    label,
    options,
    selectedValues = [],
    onSelectedValueChange,
    variant,
    inline,
    swapRight,
    className,
    labelClassName,
    required,
    isInvalid: invalid,
    errorMessage,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid2(props["aria-invalid"]) || invalid;
    const localOptions = React5.useMemo(() => {
      return options.map((option) => {
        if (typeof option === "string" || typeof option === "number") {
          return { label: option.toString(), value: option.toString(), key: option.toString() };
        }
        return option;
      });
    }, [options]);
    return /* @__PURE__ */ jsxs5(Fragment4, { children: [
      /* @__PURE__ */ jsxs5(Box, { className: "grid gap-4", children: [
        label && /* @__PURE__ */ jsx21(Label, { required, className: labelClassName, isInvalid, children: label }),
        /* @__PURE__ */ jsx21(
          Box,
          {
            className: cn19(
              "grid gap-3",
              {
                "auto-cols-max grid-flow-col gap-4": inline
              },
              className
            ),
            ref,
            children: localOptions.map((option) => /* @__PURE__ */ jsx21(
              Checkbox,
              {
                variant,
                id: option.key || option.value,
                checked: selectedValues?.includes(option.value),
                swapRight,
                className: option.className,
                labelClassName: "font-normal",
                label: option.labelContent || option.label,
                disabled: option.disabled,
                isInvalid,
                onCheckedChange: (checked) => {
                  return checked ? onSelectedValueChange([...selectedValues, option.value]) : onSelectedValueChange(selectedValues?.filter((value) => value !== option.value));
                }
              },
              option.key || option.value
            ))
          }
        )
      ] }),
      isInvalid && /* @__PURE__ */ jsx21(ErrorMessage, { message: errorMessage })
    ] });
  }
);
CheckboxGroup.displayName = "CheckboxGroup";

// src/components/Combobox/Combobox.tsx
import React9, { useEffect as useEffect2, useMemo as useMemo2, useState as useState3 } from "react";
import { CaretSortIcon, XCircleIcon } from "@paalan/react-icons";
import { cn as cn25, isAriaInvalid as isAriaInvalid3 } from "@paalan/react-shared/lib";

// src/components/Popover/Popover.tsx
import * as React6 from "react";
import { cn as cn20 } from "@paalan/react-shared/lib";
import * as PopoverPrimitive from "@radix-ui/react-popover";
import { jsx as jsx22, jsxs as jsxs6 } from "react/jsx-runtime";
var PopoverRoot = PopoverPrimitive.Root;
var PopoverTrigger = PopoverPrimitive.Trigger;
var PopoverContent = React6.forwardRef(({ className, align = "center", sideOffset = 4, ...props }, ref) => /* @__PURE__ */ jsx22(PopoverPrimitive.Portal, { children: /* @__PURE__ */ jsx22(
  PopoverPrimitive.Content,
  {
    ref,
    align,
    sideOffset,
    className: cn20(
      "relative z-50 min-w-[var(--radix-popper-anchor-width)] rounded-md border bg-popover p-4 text-popover-foreground shadow-md outline-none data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      className
    ),
    ...props
  }
) }));
PopoverContent.displayName = PopoverPrimitive.Content.displayName;
var Popover = ({ trigger, triggerClassName, contentClassName, content, ...props }) => {
  return /* @__PURE__ */ jsxs6(PopoverRoot, { ...props, children: [
    trigger && /* @__PURE__ */ jsx22(PopoverTrigger, { asChild: true, className: triggerClassName, children: trigger }),
    content && /* @__PURE__ */ jsx22(PopoverContent, { className: contentClassName, children: content })
  ] });
};
Popover.displayName = "Popover";

// src/components/Popover/components/PopoverModalContent.tsx
import { useEffect, useMemo, useRef as useRef2, useState as useState2 } from "react";
import { CheckIcon as CheckIcon2 } from "@paalan/react-icons";
import { cn as cn24 } from "@paalan/react-shared/lib";

// src/components/Command/Command.tsx
import * as React8 from "react";
import { MagnifyingGlassIcon } from "@paalan/react-icons";
import { cn as cn22 } from "@paalan/react-shared/lib";
import { Command as CommandPrimitive } from "cmdk";

// src/components/Dialog/Dialog.tsx
import * as React7 from "react";
import { Cross2Icon } from "@paalan/react-icons";
import { cn as cn21 } from "@paalan/react-shared/lib";
import * as DialogPrimitive from "@radix-ui/react-dialog";
import { jsx as jsx23, jsxs as jsxs7 } from "react/jsx-runtime";
var DialogRoot = DialogPrimitive.Root;
var DialogTrigger = DialogPrimitive.Trigger;
var DialogPortal = ({ ...props }) => /* @__PURE__ */ jsx23(DialogPrimitive.Portal, { ...props });
DialogPortal.displayName = DialogPrimitive.Portal.displayName;
var DialogOverlay = React7.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx23(
  DialogPrimitive.Overlay,
  {
    ref,
    className: cn21(
      "fixed inset-0 z-50 bg-background/80 backdrop-blur-sm data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0",
      className
    ),
    ...props
  }
));
DialogOverlay.displayName = DialogPrimitive.Overlay.displayName;
var DialogContent = React7.forwardRef(({ className, children, ...props }, ref) => /* @__PURE__ */ jsxs7(DialogPortal, { children: [
  /* @__PURE__ */ jsx23(DialogOverlay, {}),
  /* @__PURE__ */ jsxs7(
    DialogPrimitive.Content,
    {
      ref,
      className: cn21(
        "fixed left-[50%] top-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border bg-background p-6 shadow-lg duration-200 data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-left-1/2 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-left-1/2 data-[state=open]:slide-in-from-top-[48%] sm:rounded-lg md:w-full",
        className
      ),
      ...props,
      children: [
        children,
        /* @__PURE__ */ jsxs7(DialogPrimitive.Close, { className: "absolute right-4 top-4 rounded-sm opacity-70 ring-offset-background transition-opacity hover:opacity-100 focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2 disabled:pointer-events-none data-[state=open]:bg-accent data-[state=open]:text-muted-foreground", children: [
          /* @__PURE__ */ jsx23(Cross2Icon, { className: "size-4" }),
          /* @__PURE__ */ jsx23("span", { className: "sr-only", children: "Close" })
        ] })
      ]
    }
  )
] }));
DialogContent.displayName = DialogPrimitive.Content.displayName;
var DialogHeader = ({ className, ...props }) => /* @__PURE__ */ jsx23("div", { className: cn21("flex flex-col space-y-1.5 text-center sm:text-left", className), ...props });
DialogHeader.displayName = "DialogHeader";
var DialogFooter = ({ className, ...props }) => /* @__PURE__ */ jsx23("div", { className: cn21("flex flex-col-reverse sm:flex-row sm:justify-end sm:space-x-2", className), ...props });
DialogFooter.displayName = "DialogFooter";
var DialogTitle = React7.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx23(
  DialogPrimitive.Title,
  {
    ref,
    className: cn21("text-lg font-semibold leading-none tracking-tight", className),
    ...props
  }
));
DialogTitle.displayName = DialogPrimitive.Title.displayName;
var DialogDescription = React7.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx23(DialogPrimitive.Description, { ref, className: cn21("text-sm text-muted-foreground", className), ...props }));
DialogDescription.displayName = DialogPrimitive.Description.displayName;
var Dialog = ({
  content,
  children,
  trigger,
  triggerClassName,
  header,
  contentClassName,
  footer,
  ...props
}) => {
  const dialogContent = content || children;
  return /* @__PURE__ */ jsxs7(DialogRoot, { ...props, children: [
    trigger && /* @__PURE__ */ jsx23(DialogTrigger, { asChild: true, className: triggerClassName, children: trigger }),
    /* @__PURE__ */ jsxs7(DialogContent, { className: cn21(contentClassName), children: [
      header && /* @__PURE__ */ jsxs7(DialogHeader, { className: header.className, children: [
        header.title && /* @__PURE__ */ jsx23(DialogTitle, { children: header.title }),
        /* @__PURE__ */ jsx23(DialogDescription, { children: header.description })
      ] }),
      dialogContent,
      footer && /* @__PURE__ */ jsx23(DialogFooter, { className: footer.className, children: footer.content })
    ] })
  ] });
};
Dialog.displayName = "Dialog";

// src/components/Command/Command.tsx
import { jsx as jsx24, jsxs as jsxs8 } from "react/jsx-runtime";
var CommandModal = React8.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx24(
  CommandPrimitive,
  {
    ref,
    className: cn22(
      "flex h-full w-full flex-col overflow-hidden rounded-md bg-popover text-popover-foreground",
      className
    ),
    ...props
  }
));
CommandModal.displayName = CommandPrimitive.displayName;
var CommandDialog = ({ children, ...props }) => {
  return /* @__PURE__ */ jsx24(DialogRoot, { ...props, children: /* @__PURE__ */ jsx24(DialogContent, { className: "overflow-hidden p-0", children: /* @__PURE__ */ jsx24(CommandModal, { className: "[&_[cmdk-group-heading]]:px-2 [&_[cmdk-group-heading]]:font-medium [&_[cmdk-group-heading]]:text-muted-foreground [&_[cmdk-group]:not([hidden])_~[cmdk-group]]:pt-0 [&_[cmdk-group]]:px-2 [&_[cmdk-input-wrapper]_svg]:size-5 [&_[cmdk-input]]:h-12 [&_[cmdk-item]]:px-2 [&_[cmdk-item]]:py-3 [&_[cmdk-item]_svg]:size-5", children }) }) });
};
var CommandInput = React8.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsxs8("div", { className: "flex items-center border-b px-3", "data-cmdk-input-wrapper": "", children: [
  /* @__PURE__ */ jsx24(MagnifyingGlassIcon, { className: "mr-2 size-4 shrink-0 opacity-50" }),
  /* @__PURE__ */ jsx24(
    CommandPrimitive.Input,
    {
      ref,
      className: cn22(
        "flex h-10 w-full rounded-md bg-transparent py-3 text-sm outline-none placeholder:text-muted-foreground disabled:cursor-not-allowed disabled:opacity-50",
        className
      ),
      ...props
    }
  )
] }));
CommandInput.displayName = CommandPrimitive.Input.displayName;
var CommandList = React8.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx24(
  CommandPrimitive.List,
  {
    ref,
    className: cn22("max-h-[300px] overflow-y-auto overflow-x-hidden", className),
    ...props
  }
));
CommandList.displayName = CommandPrimitive.List.displayName;
var CommandEmpty = React8.forwardRef((props, ref) => /* @__PURE__ */ jsx24(CommandPrimitive.Empty, { ref, className: "py-6 text-center text-sm", ...props }));
CommandEmpty.displayName = CommandPrimitive.Empty.displayName;
var CommandGroup = React8.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx24(
  CommandPrimitive.Group,
  {
    ref,
    className: cn22(
      "overflow-hidden p-1 text-foreground [&_[cmdk-group-heading]]:px-2 [&_[cmdk-group-heading]]:py-1.5 [&_[cmdk-group-heading]]:text-xs [&_[cmdk-group-heading]]:font-medium [&_[cmdk-group-heading]]:text-muted-foreground",
      className
    ),
    ...props
  }
));
CommandGroup.displayName = CommandPrimitive.Group.displayName;
var CommandSeparator = React8.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx24(CommandPrimitive.Separator, { ref, className: cn22("-mx-1 h-px bg-border", className), ...props }));
CommandSeparator.displayName = CommandPrimitive.Separator.displayName;
var CommandLoading = React8.forwardRef(({ ...props }, ref) => /* @__PURE__ */ jsx24(CommandPrimitive.Loading, { ref, ...props }));
CommandLoading.displayName = CommandPrimitive.Loading.displayName;
var CommandItem = React8.forwardRef(({ className, onSelect, ...props }, ref) => {
  return /* @__PURE__ */ jsx24(
    CommandPrimitive.Item,
    {
      ref,
      ...props,
      className: cn22(
        "relative flex cursor-pointer select-none items-center rounded-sm px-2 py-1.5 text-sm outline-none aria-selected:bg-accent aria-selected:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",
        className
      ),
      onSelect: (value) => {
        onSelect?.(props.value ?? value);
      }
    }
  );
});
CommandItem.displayName = CommandPrimitive.Item.displayName;
var CommandShortcut = ({ className, ...props }) => {
  return /* @__PURE__ */ jsx24("span", { className: cn22("ml-auto text-xs tracking-widest text-muted-foreground", className), ...props });
};
CommandShortcut.displayName = "CommandShortcut";
var Command = ({
  inputOptions,
  emptyResultContent = "No results found.",
  groups,
  ...props
}) => {
  return /* @__PURE__ */ jsxs8(CommandDialog, { ...props, children: [
    /* @__PURE__ */ jsx24(CommandInput, { placeholder: "Search...", ...inputOptions }),
    /* @__PURE__ */ jsxs8(CommandList, { children: [
      /* @__PURE__ */ jsx24(CommandEmpty, { children: emptyResultContent }),
      groups.map(({ items, ...group }, index) => /* @__PURE__ */ jsxs8(React8.Fragment, { children: [
        /* @__PURE__ */ jsx24(CommandGroup, { ...group, children: items.map(({ icon, label, shortcut, ...item }) => /* @__PURE__ */ jsxs8(CommandItem, { ...item, id: `${group.heading} - ${label}`, children: [
          icon && /* @__PURE__ */ jsx24(Text, { as: "span", className: "mr-2", children: icon }),
          /* @__PURE__ */ jsx24(Text, { as: "span", className: "text-sm", children: label }),
          shortcut && /* @__PURE__ */ jsx24(CommandShortcut, { children: shortcut })
        ] }, label)) }),
        index !== groups.length && /* @__PURE__ */ jsx24(CommandSeparator, {})
      ] }, group.heading))
    ] })
  ] });
};
Command.displayName = "Command";
var CommandNoResultFound = ({
  optionsLength,
  emptyOptionMessage,
  emptyOptionContent,
  searchValue,
  initialSearchContent
}) => {
  if (optionsLength > 0) return null;
  if (!searchValue && initialSearchContent) {
    return typeof initialSearchContent === "string" ? /* @__PURE__ */ jsx24(Box, { className: "py-6 text-center text-sm", children: initialSearchContent }) : initialSearchContent;
  }
  if (emptyOptionContent) return emptyOptionContent;
  return /* @__PURE__ */ jsxs8(Box, { className: "py-6 text-center text-sm", children: [
    emptyOptionMessage ?? `No results found${searchValue ? ` for "${searchValue}"` : ""}`,
    "."
  ] });
};
CommandNoResultFound.displayName = "CommandNoResultFound";

// src/components/Loading/Loading.tsx
import { LoadingIcon } from "@paalan/react-icons";
import { cn as cn23 } from "@paalan/react-shared/lib";
import { jsx as jsx25, jsxs as jsxs9 } from "react/jsx-runtime";
var Loading = ({ className, spin = true, content, parentClassName, ...props }) => {
  return /* @__PURE__ */ jsxs9(Flex, { className: cn23("inline-flex items-center gap-2 text-gray-800 dark:text-gray-200", parentClassName), children: [
    /* @__PURE__ */ jsx25(
      LoadingIcon,
      {
        ...props,
        className: cn23(
          "text-gray-500 dark:text-gray-50",
          {
            "animate-spin": !!spin
          },
          className
        )
      }
    ),
    content
  ] });
};

// src/components/Popover/components/PopoverModalContent.tsx
import { jsx as jsx26, jsxs as jsxs10 } from "react/jsx-runtime";
var PopoverModalContent = ({
  searchPlaceholder = "Search...",
  emptyOptionMessage,
  emptyOptionContent,
  options,
  value,
  onValueChange,
  onSearchValueChange,
  commandClassName,
  commandInputClassName,
  commandGroupClassName,
  commandItemClassName,
  checkIconClassName,
  filter,
  filterBy = "label",
  isMulti,
  isLoading,
  loadingText = "Loading...",
  searchValue: searchValueProp,
  initialSearchContent
}) => {
  const [searchValue, setSearchValue] = useState2(searchValueProp || "");
  const filterRef = useRef2(filter);
  useEffect(() => {
    setSearchValue(searchValueProp || "");
  }, [searchValueProp]);
  useEffect(() => {
    filterRef.current = filter;
  }, [filter]);
  const filteredOptions = useMemo(() => {
    if (!searchValue) return options;
    if (typeof filterRef.current === "function") {
      return options.filter((option, index) => filterRef.current?.(option, searchValue, index));
    }
    const filterKeys = filterBy === "both" ? ["label", "value"] : [filterBy];
    return options.filter((option) => {
      return filterKeys.some((key) => {
        const value2 = option[key];
        if (typeof value2 === "string") {
          return value2.toLowerCase().includes(searchValue.toLowerCase());
        }
        return false;
      });
    });
  }, [searchValue, filterBy, options]);
  const sortedOptions = useMemo(() => {
    return filteredOptions.sort((a, b) => {
      return a.label.localeCompare(b.label);
    });
  }, [filteredOptions]);
  const checkIconClassNameFn = (value2) => {
    return typeof checkIconClassName === "function" ? checkIconClassName(value2) : checkIconClassName;
  };
  const handleSearchValueChange = (search) => {
    setSearchValue(search);
    onSearchValueChange?.(search);
  };
  return /* @__PURE__ */ jsxs10(CommandModal, { className: commandClassName, shouldFilter: false, loop: true, children: [
    /* @__PURE__ */ jsx26(
      CommandInput,
      {
        placeholder: searchPlaceholder,
        className: cn24("border-transparent focus:border-transparent focus:ring-0", commandInputClassName),
        value: searchValue,
        onValueChange: handleSearchValueChange
      }
    ),
    !isLoading && /* @__PURE__ */ jsx26(
      CommandNoResultFound,
      {
        emptyOptionMessage,
        emptyOptionContent,
        optionsLength: sortedOptions.length,
        searchValue: searchValueProp ?? searchValue,
        initialSearchContent
      }
    ),
    /* @__PURE__ */ jsx26(CommandGroup, { className: cn24("max-h-64 overflow-auto", commandGroupClassName), children: isLoading ? /* @__PURE__ */ jsx26(CommandLoading, { children: /* @__PURE__ */ jsx26(Box, { className: "p-3 text-center", children: /* @__PURE__ */ jsx26(Loading, { boxSize: "5", content: loadingText }) }) }) : sortedOptions.map((option) => /* @__PURE__ */ jsxs10(
      CommandItem,
      {
        value: option.value,
        className: cn24("flex cursor-pointer", commandItemClassName, option.className),
        disabled: option.disabled,
        onSelect: (currentValue) => {
          onValueChange?.(currentValue === value ? "" : currentValue);
        },
        children: [
          isMulti && /* @__PURE__ */ jsx26(CheckIcon2, { className: cn24("mr-2 h-4 w-4", checkIconClassNameFn(option.value)) }),
          option.labelContent || option.label,
          !isMulti && /* @__PURE__ */ jsx26(
            CheckIcon2,
            {
              className: cn24(
                "ml-auto h-4 w-4",
                value === option.value ? "opacity-100" : "opacity-0",
                checkIconClassNameFn(option.value)
              )
            }
          )
        ]
      },
      option.key || option.value
    )) })
  ] });
};
PopoverModalContent.displayName = "PopoverModalContent";

// src/components/Combobox/Combobox.tsx
import { Fragment as Fragment6, jsx as jsx27, jsxs as jsxs11 } from "react/jsx-runtime";
var Combobox = React9.forwardRef(
  ({
    label,
    options,
    placeholder = "Select",
    required,
    value,
    onValueChange,
    onBlur,
    isInvalid: invalid,
    disabled,
    inline,
    triggerClassName,
    contentClassName,
    commandInputClassName = "h-9",
    className,
    id,
    errorMessage,
    open: defaultOpen = false,
    onOpenChange,
    onClear,
    ...popoverModalContentProps
  }, ref) => {
    const [open, setOpen] = useState3(defaultOpen);
    const [localValue, setLocalValue] = useState3(value);
    const [selectedOption, setSelectedOption] = useState3(null);
    useEffect2(() => {
      setOpen(defaultOpen);
    }, [defaultOpen]);
    const isInvalid = isAriaInvalid3(popoverModalContentProps["aria-invalid"]) || invalid;
    const labelId = id || label?.toString().toLowerCase().replace(/\s/g, "-") || "";
    const localOptions = useMemo2(() => {
      return options.map((option) => {
        if (typeof option === "string" || typeof option === "number") {
          return {
            value: option.toString(),
            label: option.toString(),
            key: option.toString()
          };
        }
        return option;
      });
    }, [options]);
    useEffect2(() => {
      setLocalValue(value);
    }, [value]);
    const onOpenChangeHandle = (open2) => {
      setOpen(open2);
      onOpenChange?.(open2);
    };
    const handleValueChange = (newValue) => {
      setLocalValue(newValue);
      onValueChange?.(newValue);
      setSelectedOption(localOptions.find((option) => option.value === newValue) || null);
      onOpenChangeHandle(false);
    };
    const valueLabel = useMemo2(() => {
      if (!localValue) return null;
      const selectedLocalOption = localOptions.find((option) => option.value === localValue);
      if (selectedLocalOption) return selectedLocalOption.label;
      return selectedOption?.label;
    }, [localOptions, localValue, selectedOption]);
    return /* @__PURE__ */ jsxs11(Fragment6, { children: [
      /* @__PURE__ */ jsxs11(
        Box,
        {
          className: cn25(
            "flex w-full flex-col gap-2",
            {
              "flex-row items-center": inline
            },
            className
          ),
          children: [
            label && /* @__PURE__ */ jsx27(Label, { htmlFor: labelId, required, isInvalid, children: label }),
            /* @__PURE__ */ jsxs11(PopoverRoot, { open, onOpenChange: onOpenChangeHandle, children: [
              /* @__PURE__ */ jsx27(PopoverTrigger, { asChild: true, children: /* @__PURE__ */ jsxs11(
                Button,
                {
                  variant: "outline",
                  role: "combobox",
                  "aria-expanded": open,
                  disabled,
                  className: cn25(
                    "w-full justify-between",
                    {
                      "text-muted-foreground hover:text-muted-foreground": !localValue,
                      "border-danger text-danger hover:bg-background hover:text-danger focus:ring-danger/40": isInvalid
                    },
                    triggerClassName
                  ),
                  onBlur,
                  ref,
                  id: labelId,
                  children: [
                    valueLabel ? valueLabel : /* @__PURE__ */ jsx27(Text, { fontSize: "sm", className: "font-normal", children: placeholder }),
                    valueLabel ? /* @__PURE__ */ jsx27(
                      XCircleIcon,
                      {
                        className: "ml-auto size-4 shrink-0 cursor-pointer opacity-50 hover:opacity-100",
                        onClick: (e) => {
                          e.stopPropagation();
                          handleValueChange("");
                          onClear?.();
                        }
                      }
                    ) : /* @__PURE__ */ jsx27(CaretSortIcon, { className: "ml-auto size-4 shrink-0 opacity-50" })
                  ]
                }
              ) }),
              /* @__PURE__ */ jsx27(PopoverContent, { className: cn25("w-full p-0", contentClassName), children: /* @__PURE__ */ jsx27(
                PopoverModalContent,
                {
                  ...popoverModalContentProps,
                  commandInputClassName,
                  options: localOptions,
                  value: localValue,
                  onValueChange: handleValueChange
                }
              ) })
            ] })
          ]
        }
      ),
      isInvalid && /* @__PURE__ */ jsx27(ErrorMessage, { message: errorMessage })
    ] });
  }
);

// src/components/DatePicker/DatePicker.tsx
import React11 from "react";
import { CalendarIcon, XCircleIcon as XCircleIcon2 } from "@paalan/react-icons";
import { cn as cn28, isAriaInvalid as isAriaInvalid5 } from "@paalan/react-shared/lib";
import { addDays, format } from "date-fns";

// src/components/Calendar/Calendar.tsx
import { ChevronLeftIcon, ChevronRightIcon } from "@paalan/react-icons";
import { cn as cn26 } from "@paalan/react-shared/lib";
import { DayPicker } from "react-day-picker";
import { jsx as jsx28 } from "react/jsx-runtime";
var Calendar = ({ className, classNames, showOutsideDays = true, components, ...props }) => {
  return /* @__PURE__ */ jsx28(
    DayPicker,
    {
      showOutsideDays,
      className: cn26("p-3", className),
      classNames: {
        months: "flex flex-col sm:flex-row space-y-4 sm:space-x-4 sm:space-y-0",
        month: "space-y-4",
        caption: "flex justify-center pt-1 relative items-center",
        caption_label: "text-sm font-medium",
        nav: "space-x-1 flex items-center",
        nav_button: cn26(
          buttonVariants({ variant: "outline" }),
          "h-7 w-7 bg-transparent p-0 opacity-50 hover:opacity-100"
        ),
        nav_button_previous: "absolute left-1",
        nav_button_next: "absolute right-1",
        table: "w-full border-collapse space-y-1",
        head_row: "flex",
        head_cell: "text-muted-foreground rounded-md w-8 font-normal text-[0.8rem]",
        row: "flex w-full mt-2",
        cell: cn26(
          "relative p-0 text-center text-sm focus-within:relative focus-within:z-20 [&:has([aria-selected])]:bg-accent",
          props.mode === "range" ? "[&:has(>.day-range-end)]:rounded-r-md [&:has(>.day-range-start)]:rounded-l-md first:[&:has([aria-selected])]:rounded-l-md last:[&:has([aria-selected])]:rounded-r-md" : "[&:has([aria-selected])]:rounded-md"
        ),
        day: cn26(buttonVariants({ variant: "ghost" }), "h-8 w-8 p-0 font-normal aria-selected:opacity-100"),
        day_range_start: "day-range-start",
        day_range_end: "day-range-end",
        day_selected: "bg-primary text-primary-foreground hover:bg-primary hover:text-primary-foreground focus:bg-primary focus:text-primary-foreground",
        day_today: "bg-accent text-accent-foreground",
        day_outside: "text-muted-foreground opacity-50",
        day_disabled: "text-muted-foreground opacity-50",
        day_range_middle: "aria-selected:bg-accent aria-selected:text-accent-foreground",
        day_hidden: "invisible",
        ...classNames
      },
      components: {
        IconLeft: () => /* @__PURE__ */ jsx28(ChevronLeftIcon, { className: "size-4" }),
        IconRight: () => /* @__PURE__ */ jsx28(ChevronRightIcon, { className: "size-4" }),
        ...components
      },
      ...props
    }
  );
};
Calendar.displayName = "Calendar";

// src/components/Select/Select.tsx
import * as React10 from "react";
import { useControllableState as useControllableState2 } from "@paalan/react-hooks";
import { CaretSortIcon as CaretSortIcon2, CheckIcon as CheckIcon3 } from "@paalan/react-icons";
import { cn as cn27, isAriaInvalid as isAriaInvalid4, isDefinedValue } from "@paalan/react-shared/lib";
import * as SelectPrimitive from "@radix-ui/react-select";

// src/components/Select/helper.ts
var isSelectOptionGroup = (option) => {
  return Object.hasOwnProperty.call(option, "options");
};

// src/components/Select/Select.tsx
import { Fragment as Fragment8, jsx as jsx29, jsxs as jsxs12 } from "react/jsx-runtime";
var SelectRoot = SelectPrimitive.Root;
var SelectGroup = SelectPrimitive.Group;
var SelectValue = SelectPrimitive.Value;
var SelectTrigger = React10.forwardRef(({ className, children, ...props }, ref) => /* @__PURE__ */ jsxs12(
  SelectPrimitive.Trigger,
  {
    ref,
    className: cn27(
      "flex h-9 w-full items-center justify-between rounded-md border border-input bg-transparent px-3 py-2 text-sm shadow-sm ring-offset-background placeholder:text-muted-foreground focus-visible:border-transparent focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",
      className
    ),
    ...props,
    children: [
      children,
      /* @__PURE__ */ jsx29(SelectPrimitive.Icon, { asChild: true, children: /* @__PURE__ */ jsx29(CaretSortIcon2, { className: "size-4 opacity-80" }) })
    ]
  }
));
SelectTrigger.displayName = SelectPrimitive.Trigger.displayName;
var SelectContent = React10.forwardRef(({ className, children, position = "popper", ...props }, ref) => /* @__PURE__ */ jsx29(SelectPrimitive.Portal, { children: /* @__PURE__ */ jsx29(
  SelectPrimitive.Content,
  {
    ref,
    className: cn27(
      "relative z-50 min-w-[8rem] overflow-hidden rounded-md border bg-popover text-popover-foreground shadow-md data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      position === "popper" && "data-[side=bottom]:translate-y-1 data-[side=left]:-translate-x-1 data-[side=right]:translate-x-1 data-[side=top]:-translate-y-1",
      className
    ),
    position,
    ...props,
    children: /* @__PURE__ */ jsx29(
      SelectPrimitive.Viewport,
      {
        className: cn27(
          "p-1",
          position === "popper" && "h-[var(--radix-select-trigger-height)] w-full min-w-[var(--radix-select-trigger-width)]"
        ),
        children
      }
    )
  }
) }));
SelectContent.displayName = SelectPrimitive.Content.displayName;
var SelectLabel = React10.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx29(SelectPrimitive.Label, { ref, className: cn27("px-2 py-1.5 text-sm font-semibold", className), ...props }));
SelectLabel.displayName = SelectPrimitive.Label.displayName;
var SelectItem = React10.forwardRef(({ className, children, ...props }, ref) => /* @__PURE__ */ jsxs12(
  SelectPrimitive.Item,
  {
    ref,
    className: cn27(
      "relative flex w-full cursor-default select-none items-center rounded-sm py-1.5 pl-2 pr-8 text-sm outline-none focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",
      className
    ),
    ...props,
    children: [
      /* @__PURE__ */ jsx29("span", { className: "absolute right-2 flex size-3.5 items-center justify-center", children: /* @__PURE__ */ jsx29(SelectPrimitive.ItemIndicator, { children: /* @__PURE__ */ jsx29(CheckIcon3, { className: "size-4" }) }) }),
      /* @__PURE__ */ jsx29(SelectPrimitive.ItemText, { children })
    ]
  }
));
SelectItem.displayName = SelectPrimitive.Item.displayName;
var SelectSeparator = React10.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx29(SelectPrimitive.Separator, { ref, className: cn27("-mx-1 my-1 h-px bg-muted", className), ...props }));
SelectSeparator.displayName = SelectPrimitive.Separator.displayName;
var Select = React10.forwardRef(
  ({
    placeholder = "Select",
    label,
    triggerClassName,
    contentClassName,
    options,
    id,
    required,
    value,
    defaultValue,
    onValueChange,
    onBlur,
    isInvalid: invalid,
    inline,
    className,
    errorMessage,
    noOptionsMessage = "No option found.",
    ...props
  }, ref) => {
    const [localValue, setLocalValue] = useControllableState2({
      value: isDefinedValue(value) ? value : "",
      defaultValue: isDefinedValue(defaultValue) ? defaultValue : "",
      onChange: onValueChange
    });
    const labelId = id ? id : label ? label.toString().toLowerCase().replace(/\s/g, "-") : void 0;
    const isInvalid = isAriaInvalid4(props["aria-invalid"]) || invalid;
    const groups = React10.useMemo(() => {
      const groupArray = [];
      options.forEach((option) => {
        if (typeof option === "string" || typeof option === "number") {
          if (!groupArray.length) {
            groupArray.push({ options: [] });
          }
          if (option) {
            groupArray[0].options.push({ key: option.toString(), label: option.toString(), value: option.toString() });
          }
        } else if (isSelectOptionGroup(option)) {
          groupArray.push(option);
        } else {
          if (!groupArray.length) {
            groupArray.push({ options: [] });
          }
          groupArray[0].options.push(option);
        }
      });
      return groupArray;
    }, [options]);
    const selectedOption = React10.useMemo(() => {
      if (!localValue) return null;
      for (const group of groups) {
        for (const option of group.options) {
          if (option.value === localValue) {
            return option;
          }
        }
      }
      return null;
    }, [groups, localValue]);
    return /* @__PURE__ */ jsxs12(Fragment8, { children: [
      /* @__PURE__ */ jsxs12(
        Box,
        {
          className: cn27(
            "flex w-full flex-col gap-2",
            {
              "flex-row items-center": inline
            },
            className
          ),
          children: [
            label && /* @__PURE__ */ jsx29(Label, { htmlFor: labelId, required, children: label }),
            /* @__PURE__ */ jsxs12(SelectRoot, { ...props, required, value: localValue, onValueChange: setLocalValue, children: [
              /* @__PURE__ */ jsx29(
                SelectTrigger,
                {
                  className: cn27(
                    !localValue && "text-muted-foreground",
                    {
                      "border-danger text-danger focus-visible:ring-danger/40 ": isInvalid
                    },
                    triggerClassName
                  ),
                  id: labelId,
                  ref,
                  onBlur,
                  children: /* @__PURE__ */ jsx29(SelectValue, { placeholder, children: selectedOption?.label || localValue || placeholder })
                }
              ),
              /* @__PURE__ */ jsx29(SelectContent, { className: contentClassName, children: !groups.length ? /* @__PURE__ */ jsx29(Text, { className: "px-3 py-1 text-center text-sm text-gray-500", children: noOptionsMessage }) : groups.map((group, index) => /* @__PURE__ */ jsxs12(React10.Fragment, { children: [
                /* @__PURE__ */ jsxs12(SelectGroup, { children: [
                  group.label && /* @__PURE__ */ jsx29(SelectLabel, { children: group.label }),
                  group.options.map((option) => /* @__PURE__ */ jsx29(
                    SelectItem,
                    {
                      className: cn27("cursor-pointer", option.className),
                      value: option.value,
                      disabled: option.disabled,
                      children: option.labelContent || option.label
                    },
                    option.key || option.value
                  ))
                ] }),
                index !== groups.length - 1 && /* @__PURE__ */ jsx29(SelectSeparator, {})
              ] }, `${group.label || ""}${index.toString()}`)) })
            ] })
          ]
        }
      ),
      isInvalid && /* @__PURE__ */ jsx29(ErrorMessage, { message: errorMessage })
    ] });
  }
);
Select.displayName = "Select";

// src/components/DatePicker/DatePicker.tsx
import { Fragment as Fragment9, jsx as jsx30, jsxs as jsxs13 } from "react/jsx-runtime";
var PresetCalendar = ({
  presets,
  date,
  onDateChange,
  presetPlaceholder = "Select"
}) => {
  const selectedDate = typeof date === "string" ? new Date(date) : date;
  return /* @__PURE__ */ jsxs13(Fragment9, { children: [
    /* @__PURE__ */ jsxs13(SelectRoot, { onValueChange: (value) => onDateChange?.(addDays(/* @__PURE__ */ new Date(), parseInt(value))), children: [
      /* @__PURE__ */ jsx30(SelectTrigger, { children: /* @__PURE__ */ jsx30(SelectValue, { placeholder: presetPlaceholder }) }),
      /* @__PURE__ */ jsx30(SelectContent, { position: "popper", children: (presets || []).map((preset) => /* @__PURE__ */ jsx30(SelectItem, { value: `${preset.value}`, children: preset.label }, preset.value)) })
    ] }),
    /* @__PURE__ */ jsx30("div", { className: "rounded-md border", children: /* @__PURE__ */ jsx30(Calendar, { mode: "single", selected: selectedDate, onSelect: onDateChange }) })
  ] });
};
var DatePicker = React11.forwardRef(
  ({
    date: value,
    onDateChange: onValueChange,
    label,
    className,
    parentClassName,
    placeholder = "Pick a date",
    dateFormat = "PPP",
    presetPlaceholder,
    presets,
    isInvalid: invalid,
    required,
    id,
    errorMessage,
    disabled,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid5(props["aria-invalid"]) || invalid;
    const selectedDate = React11.useMemo(() => typeof value === "string" ? new Date(value) : value, [value]);
    const [date, setDate] = React11.useState(selectedDate);
    const labelId = id || label?.toLowerCase().replace(/\s/g, "-");
    React11.useEffect(() => {
      if (selectedDate) {
        setDate(selectedDate);
      }
    }, [selectedDate]);
    const onSelect = React11.useCallback(
      (date2) => {
        setDate(date2);
        onValueChange?.(date2 ? new Date(date2) : void 0);
      },
      [onValueChange]
    );
    const isPreset = presets && presets.length > 0;
    return /* @__PURE__ */ jsxs13(Fragment9, { children: [
      /* @__PURE__ */ jsxs13(Box, { className: cn28("flex flex-1 flex-col gap-2", parentClassName), children: [
        label && /* @__PURE__ */ jsx30(Label, { htmlFor: labelId, required, isInvalid, children: label }),
        /* @__PURE__ */ jsxs13(PopoverRoot, { children: [
          /* @__PURE__ */ jsx30(PopoverTrigger, { asChild: true, children: /* @__PURE__ */ jsxs13(
            Button,
            {
              ...props,
              type: "button",
              variant: "outline",
              disabled,
              className: cn28(
                "min-w-[240px] justify-start text-left font-normal",
                {
                  "text-muted-foreground": !date,
                  "border-danger text-danger hover:bg-background hover:text-danger focus:ring-danger/40": isInvalid
                },
                className
              ),
              wrapperClassName: "justify-start",
              ref,
              id: labelId,
              children: [
                /* @__PURE__ */ jsx30(CalendarIcon, { className: "mr-2 size-4" }),
                date ? format(date, dateFormat) : /* @__PURE__ */ jsx30(Box, { as: "span", children: placeholder }),
                date && /* @__PURE__ */ jsx30(
                  XCircleIcon2,
                  {
                    onClick: (e) => {
                      e.stopPropagation();
                      onSelect(void 0);
                    },
                    title: "Clear date",
                    className: cn28("ml-auto h-5 w-5 text-muted-foreground", {
                      "text-danger": isInvalid
                    })
                  }
                )
              ]
            }
          ) }),
          /* @__PURE__ */ jsx30(
            PopoverContent,
            {
              className: cn28("min-w-fit", isPreset ? "flex w-auto flex-col space-y-2 p-2" : "w-auto p-0"),
              align: "start",
              children: isPreset ? /* @__PURE__ */ jsx30(
                PresetCalendar,
                {
                  presets,
                  date,
                  onDateChange: onSelect,
                  presetPlaceholder
                }
              ) : /* @__PURE__ */ jsx30(Calendar, { mode: "single", selected: date, onSelect, initialFocus: true })
            }
          )
        ] })
      ] }),
      isInvalid && /* @__PURE__ */ jsx30(ErrorMessage, { message: errorMessage })
    ] });
  }
);

// src/components/DateRangePicker/DateRangePicker.tsx
import * as React12 from "react";
import { CalendarIcon as CalendarIcon2, XCircleIcon as XCircleIcon3 } from "@paalan/react-icons";
import { cn as cn29, isAriaInvalid as isAriaInvalid6 } from "@paalan/react-shared/lib";
import { format as format2 } from "date-fns";
import { Fragment as Fragment10, jsx as jsx31, jsxs as jsxs14 } from "react/jsx-runtime";
var DateRangePicker = React12.forwardRef(
  ({
    dateRange: range,
    onDateRangeChange: onRangeChange,
    label,
    placeholder = "Pick a date",
    numberOfMonths = 2,
    dateFormat = "MMM dd, yyyy",
    className,
    parentClassName,
    isInvalid: invalid,
    required,
    id,
    errorMessage,
    disabled,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid6(props["aria-invalid"]) || invalid;
    const labelId = id || label?.toLowerCase().replace(/\s/g, "-");
    const [date, setDate] = React12.useState(void 0);
    React12.useEffect(() => {
      setDate(range);
    }, [range]);
    const onSelect = React12.useCallback(
      (range2) => {
        setDate(range2);
        onRangeChange?.(range2);
      },
      [onRangeChange]
    );
    return /* @__PURE__ */ jsxs14(Fragment10, { children: [
      /* @__PURE__ */ jsxs14(Box, { className: cn29("flex flex-col gap-2", parentClassName), children: [
        label && /* @__PURE__ */ jsx31(Label, { htmlFor: labelId, required, isInvalid, children: label }),
        /* @__PURE__ */ jsx31(Box, { className: cn29("grid gap-2", className), children: /* @__PURE__ */ jsxs14(PopoverRoot, { children: [
          /* @__PURE__ */ jsx31(PopoverTrigger, { asChild: true, children: /* @__PURE__ */ jsxs14(
            Button,
            {
              ...props,
              disabled,
              type: "button",
              variant: "outline",
              className: cn29("min-w-[300px] justify-start text-left font-normal", {
                "text-muted-foreground": !date,
                "border-danger text-danger hover:bg-background hover:text-danger focus:ring-danger/40": isInvalid
              }),
              wrapperClassName: "justify-start",
              ref,
              id: labelId,
              children: [
                /* @__PURE__ */ jsx31(CalendarIcon2, { className: "mr-2 size-4" }),
                date?.from ? date.to ? /* @__PURE__ */ jsxs14(Fragment10, { children: [
                  format2(date.from, dateFormat),
                  " - ",
                  format2(date.to, dateFormat)
                ] }) : format2(date.from, dateFormat) : /* @__PURE__ */ jsx31(Box, { as: "span", children: placeholder }),
                !!(date?.from || date?.to) && /* @__PURE__ */ jsx31(
                  XCircleIcon3,
                  {
                    onClick: (e) => {
                      e.stopPropagation();
                      onSelect(void 0);
                    },
                    title: "Clear date range",
                    className: cn29("ml-auto h-5 w-5 text-muted-foreground", {
                      "text-danger": isInvalid
                    })
                  }
                )
              ]
            }
          ) }),
          /* @__PURE__ */ jsx31(PopoverContent, { className: "w-auto min-w-fit p-0", align: "start", children: /* @__PURE__ */ jsx31(
            Calendar,
            {
              mode: "range",
              defaultMonth: date?.from,
              selected: date,
              onSelect,
              numberOfMonths,
              initialFocus: true
            }
          ) })
        ] }) })
      ] }),
      isInvalid && /* @__PURE__ */ jsx31(ErrorMessage, { message: errorMessage })
    ] });
  }
);

// src/components/Input/Input.tsx
import { cn as cn30, isAriaInvalid as isAriaInvalid7 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef25 } from "@paalan/react-shared/utils";
import { Fragment as Fragment11, jsx as jsx32, jsxs as jsxs15 } from "react/jsx-runtime";
var Input = forwardRef25(
  ({
    className,
    type,
    isInvalid: invalid,
    label,
    required,
    id,
    inline,
    inputClassName,
    onValueChange,
    errorMessage,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid7(props["aria-invalid"]) || invalid;
    const labelId = id || props.name || label;
    const onChangeHandle = (event) => {
      const value = event.target.value;
      onValueChange?.(value);
      props.onChange?.(event);
    };
    return /* @__PURE__ */ jsxs15(Fragment11, { children: [
      /* @__PURE__ */ jsxs15(
        Box,
        {
          className: cn30(
            "flex w-full flex-col gap-2",
            {
              "flex-row items-center": inline
            },
            className
          ),
          children: [
            label && /* @__PURE__ */ jsx32(
              Label,
              {
                htmlFor: labelId,
                required,
                className: cn30({
                  "text-danger": isInvalid
                }),
                children: label
              }
            ),
            /* @__PURE__ */ jsx32(
              Box,
              {
                ...props,
                as: "input",
                type,
                id: labelId,
                required,
                className: cn30(
                  "h-10 w-full rounded-md border border-input bg-transparent px-3 py-1 text-sm shadow-sm transition-colors file:border-0 file:bg-transparent file:text-sm file:font-medium placeholder:text-muted-foreground focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",
                  {
                    "border-danger placeholder:text-danger focus-visible:ring-danger/40": isInvalid,
                    "bg-muted/40 read-only:focus-visible:ring-0": props.readOnly
                  },
                  inputClassName
                ),
                ref,
                onChange: onChangeHandle
              }
            )
          ]
        }
      ),
      isInvalid && /* @__PURE__ */ jsx32(ErrorMessage, { message: errorMessage })
    ] });
  }
);
Input.displayName = "Input";

// src/components/MultiSelect/MultiSelect.tsx
import * as React13 from "react";
import { useCallbackRef } from "@paalan/react-hooks";
import { CaretSortIcon as CaretSortIcon3, XMarkIcon } from "@paalan/react-icons";
import { cn as cn32, isAriaInvalid as isAriaInvalid8 } from "@paalan/react-shared/lib";

// src/components/Badge/Badge.tsx
import { cn as cn31 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef26 } from "@paalan/react-shared/utils";
import { cva as cva5 } from "class-variance-authority";
import { jsx as jsx33 } from "react/jsx-runtime";
var badgeVariants = cva5(
  "inline-flex items-center rounded-md border border-transparent font-semibold transition-colors focus:outline-none focus:ring-2 focus:ring-ring focus:ring-offset-2",
  {
    variants: {
      variant: {
        primary: "bg-primary text-primary-foreground",
        secondary: "bg-secondary text-secondary-foreground",
        tertiary: "bg-tertiary text-tertiary-foreground",
        danger: "bg-danger text-danger-foreground",
        warning: "bg-warning text-warning-foreground",
        success: "bg-success text-success-foreground",
        info: "bg-info text-info-foreground",
        outline: "border-inherit text-foreground"
      },
      size: {
        sm: "px-1.5 py-0.5 text-xs",
        md: "px-2.5 py-0.5 text-xs",
        lg: "px-3 py-0.5 text-sm"
      }
    },
    defaultVariants: {
      variant: "primary",
      size: "md"
    }
  }
);
var Badge = forwardRef26(
  ({ className, label, children, variant, size, ...props }, ref) => {
    return /* @__PURE__ */ jsx33(Box, { ...props, ref, className: cn31(badgeVariants({ variant, size }), className), children: label || children });
  }
);

// src/components/MultiSelect/MultiSelect.tsx
import { Fragment as Fragment12, jsx as jsx34, jsxs as jsxs16 } from "react/jsx-runtime";
var MultiSelect = React13.forwardRef(
  ({
    label,
    options,
    placeholder = "Select",
    selectedValues = [],
    onSelectedValueChange,
    onBlur,
    triggerClassName,
    contentClassName,
    required,
    disabled,
    isInvalid: invalid,
    inline,
    id,
    errorMessage,
    open: defaultOpen = false,
    onOpenChange,
    ...popoverModalContentProps
  }, ref) => {
    const [open, setOpen] = React13.useState(defaultOpen);
    const onSelectedValueChangeRef = useCallbackRef(onSelectedValueChange);
    const isInvalid = isAriaInvalid8(popoverModalContentProps["aria-invalid"]) || invalid;
    const labelId = id || label?.toString().toLowerCase().replace(/\s/g, "-") || "";
    React13.useEffect(() => {
      setOpen(defaultOpen);
    }, [defaultOpen]);
    React13.useEffect(() => {
      if (selectedValues.length === 0) {
        onSelectedValueChangeRef([]);
      }
    }, [selectedValues.length, onSelectedValueChangeRef]);
    const localOptions = React13.useMemo(() => {
      return options.map((option) => {
        if (typeof option === "string" || typeof option === "number") {
          return {
            key: option.toString(),
            value: option.toString(),
            label: option.toString()
          };
        }
        return option;
      });
    }, [options]);
    const labelMapping = React13.useMemo(() => {
      const mapping = {};
      localOptions.forEach((option) => {
        mapping[option.value] = option.label;
      });
      return mapping;
    }, [localOptions]);
    const handleUnselect = (item) => {
      onSelectedValueChange(selectedValues.filter((i) => i !== item));
    };
    const onOpenChangeHandle = (open2) => {
      setOpen(open2);
      onOpenChange?.(open2);
    };
    return /* @__PURE__ */ jsxs16(Fragment12, { children: [
      /* @__PURE__ */ jsxs16(
        Box,
        {
          className: cn32("flex w-full flex-col gap-2", {
            "flex-row items-center": inline
          }),
          children: [
            label && /* @__PURE__ */ jsx34(Label, { htmlFor: labelId, required, isInvalid, className: "shrink-0", children: label }),
            /* @__PURE__ */ jsxs16(PopoverRoot, { open, onOpenChange: onOpenChangeHandle, children: [
              /* @__PURE__ */ jsx34(PopoverTrigger, { asChild: true, children: /* @__PURE__ */ jsxs16(
                Button,
                {
                  variant: "outline",
                  role: "combobox",
                  "aria-expanded": open,
                  disabled,
                  className: cn32("h-10 min-h-[40px] w-full justify-between hover:bg-background", triggerClassName, {
                    "h-full": selectedValues.length > 1,
                    "text-muted-foreground hover:text-muted-foreground": !selectedValues.length,
                    "border-danger text-danger hover:bg-background hover:text-danger focus:ring-danger/40": isInvalid
                  }),
                  onClick: () => setOpen(!open),
                  onBlur,
                  ref,
                  id: labelId,
                  children: [
                    selectedValues.length ? /* @__PURE__ */ jsx34(Box, { className: "flex flex-wrap gap-2", children: selectedValues.map(
                      (item) => labelMapping[item] && /* @__PURE__ */ jsxs16(Badge, { variant: "secondary", children: [
                        labelMapping[item],
                        /* @__PURE__ */ jsx34(
                          "span",
                          {
                            className: "ml-1 rounded-full outline-none ring-offset-background focus:ring-2 focus:ring-ring focus:ring-offset-2",
                            onKeyDown: (e) => {
                              if (e.key === "Enter") {
                                handleUnselect(item);
                                setOpen(false);
                              }
                            },
                            onMouseDown: (e) => {
                              e.preventDefault();
                              e.stopPropagation();
                            },
                            onClick: (e) => {
                              e.stopPropagation();
                              handleUnselect(item);
                              setOpen(false);
                            },
                            children: /* @__PURE__ */ jsx34(XMarkIcon, { className: "size-3 text-muted-foreground hover:rounded-full hover:bg-muted-foreground/40 hover:text-foreground" })
                          }
                        )
                      ] }, item)
                    ) }) : /* @__PURE__ */ jsx34(Text, { className: "text-sm font-normal", children: placeholder }),
                    /* @__PURE__ */ jsx34(CaretSortIcon3, { className: "ml-auto size-4 shrink-0 opacity-50" })
                  ]
                }
              ) }),
              /* @__PURE__ */ jsx34(PopoverContent, { className: cn32("w-full p-0", contentClassName), children: /* @__PURE__ */ jsx34(
                PopoverModalContent,
                {
                  ...popoverModalContentProps,
                  options: localOptions,
                  onValueChange: (value) => {
                    onSelectedValueChange(
                      selectedValues.includes(value) ? selectedValues.filter((item) => item !== value) : [...selectedValues, value]
                    );
                    setOpen(true);
                  },
                  isMulti: true,
                  checkIconClassName: (value) => selectedValues.includes(value) ? "opacity-100" : "opacity-0"
                }
              ) })
            ] })
          ]
        }
      ),
      isInvalid && /* @__PURE__ */ jsx34(ErrorMessage, { message: errorMessage })
    ] });
  }
);

// src/components/NumberInput/NumberInput.tsx
import { useControllableState as useControllableState3 } from "@paalan/react-hooks";
import { isDefinedValue as isDefinedValue2, isPositiveFloat, isPositiveInteger } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef28 } from "@paalan/react-shared/utils";
import { jsx as jsx35 } from "react/jsx-runtime";
var NumberInput = forwardRef28(
  ({
    isPositiveInteger: isPositiveIntegerValue,
    isPositiveFloat: isPositiveFloatValue,
    onChange,
    onValueChange,
    value,
    defaultValue,
    isPositiveIntegerStartsWithZero,
    isPositiveFloatStartsWithZero,
    zeroAsEmptyString,
    ...props
  }, ref) => {
    const [localValue, setLocalValue] = useControllableState3({
      value: isDefinedValue2(value) ? `${zeroAsEmptyString ? value || "" : value}` : "",
      defaultValue: isDefinedValue2(defaultValue) ? `${zeroAsEmptyString ? defaultValue || "" : ""}` : "",
      onChange: (value2) => onValueChange?.(+value2)
    });
    const onChangeHandle = (event) => {
      const value2 = event.target.value;
      if (value2 === "") {
        setLocalValue(value2);
        return onChange?.(event);
      }
      if (isPositiveIntegerValue) {
        if (isPositiveInteger(value2, 1)) {
          setLocalValue(value2);
          onChange?.(event);
        }
      } else if (isPositiveFloatValue) {
        if (isPositiveFloat(value2, 1)) {
          setLocalValue(value2);
          onChange?.(event);
        }
      } else if (isPositiveIntegerStartsWithZero) {
        if (isPositiveInteger(value2, 0)) {
          setLocalValue(value2);
          onChange?.(event);
        }
      } else if (isPositiveFloatStartsWithZero) {
        if (isPositiveFloat(value2, 0)) {
          setLocalValue(value2);
          onChange?.(event);
        }
      } else {
        setLocalValue(value2);
        onChange?.(event);
      }
    };
    return /* @__PURE__ */ jsx35(Input, { ...props, type: "number", value: localValue, onChange: onChangeHandle, ref });
  }
);
NumberInput.displayName = "NumberInput";

// src/components/RadioGroup/RadioGroup.tsx
import * as React14 from "react";
import { CheckIcon as CheckIcon4 } from "@paalan/react-icons";
import { cn as cn33, isAriaInvalid as isAriaInvalid9 } from "@paalan/react-shared/lib";
import * as RadioGroupPrimitive from "@radix-ui/react-radio-group";
import { cva as cva6 } from "class-variance-authority";
import { Fragment as Fragment13, jsx as jsx36, jsxs as jsxs17 } from "react/jsx-runtime";
var radioGroupVariants = cva6(
  "aspect-square size-4 rounded-full border shadow focus:outline-none focus-visible:ring-1 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",
  {
    variants: {
      variant: {
        primary: "border-primary text-primary",
        secondary: "border-secondary text-secondary",
        tertiary: "border-tertiary text-tertiary",
        info: "border-info text-info",
        success: "border-success text-success",
        warning: "border-warning text-warning",
        danger: "border-danger text-danger"
      }
    },
    defaultVariants: {
      variant: "primary"
    }
  }
);
var RadioGroupRoot = React14.forwardRef(({ className, ...props }, ref) => {
  return /* @__PURE__ */ jsx36(RadioGroupPrimitive.Root, { className: cn33("grid gap-3", className), ...props, ref });
});
RadioGroupRoot.displayName = RadioGroupPrimitive.Root.displayName;
var RadioGroupRootItem = React14.forwardRef(({ className, variant = "primary", children, ...props }, ref) => {
  return /* @__PURE__ */ jsx36(RadioGroupPrimitive.Item, { ref, className: cn33(radioGroupVariants({ variant }), className), ...props, children: /* @__PURE__ */ jsx36(RadioGroupPrimitive.Indicator, { className: "flex items-center justify-center text-current", children: /* @__PURE__ */ jsx36(CheckIcon4, { className: "size-3.5" }) }) });
});
RadioGroupRootItem.displayName = RadioGroupPrimitive.Item.displayName;
var RadioGroup = React14.forwardRef(
  ({
    options,
    value,
    onValueChange,
    inline,
    label,
    className,
    labelClassName,
    swapRight,
    isInvalid: invalid,
    variant,
    required,
    errorMessage,
    ...props
  }, ref) => {
    const isInvalid = isAriaInvalid9(props["aria-invalid"]) || invalid;
    const [selectedValue, setSelectedValue] = React14.useState(value);
    React14.useEffect(() => {
      setSelectedValue(value);
    }, [value]);
    const localOptions = React14.useMemo(() => {
      return options.map((option) => {
        if (typeof option === "string" || typeof option === "number") {
          return { label: option.toString(), value: option.toString(), key: option.toString() };
        }
        return option;
      });
    }, [options]);
    const onValueChangeHandle = (value2) => {
      setSelectedValue(value2);
      onValueChange?.(value2);
    };
    return /* @__PURE__ */ jsxs17(Fragment13, { children: [
      /* @__PURE__ */ jsxs17(Box, { className: "grid gap-4", children: [
        label && /* @__PURE__ */ jsx36(Label, { required, className: labelClassName, isInvalid, children: label }),
        /* @__PURE__ */ jsx36(
          RadioGroupRoot,
          {
            value: selectedValue,
            onValueChange: onValueChangeHandle,
            ...props,
            className: cn33(
              {
                "auto-cols-max grid-flow-col gap-5": inline
              },
              className
            ),
            ref,
            children: localOptions.map((option) => /* @__PURE__ */ jsxs17(Box, { className: "flex items-center gap-2", children: [
              /* @__PURE__ */ jsx36(
                RadioGroupRootItem,
                {
                  id: option.key || option.value,
                  value: option.value,
                  className: cn33(
                    {
                      "order-1": swapRight,
                      "border-danger data-[state=checked]:bg-danger data-[state=checked]:text-danger-foreground": isInvalid
                    },
                    option.className
                  ),
                  disabled: option.disabled,
                  variant
                }
              ),
              /* @__PURE__ */ jsx36(
                Label,
                {
                  htmlFor: option.value,
                  isInvalid,
                  className: cn33(
                    "cursor-pointer",
                    {
                      "font-normal": !!label
                    },
                    labelClassName
                  ),
                  children: option.labelContent || option.label
                }
              )
            ] }, option.key || option.value))
          }
        )
      ] }),
      isInvalid && /* @__PURE__ */ jsx36(ErrorMessage, { message: errorMessage })
    ] });
  }
);
RadioGroup.displayName = "RadioGroup";

// src/components/Textarea/Textarea.tsx
import { useEffect as useEffect6, useState as useState7 } from "react";
import { cn as cn34, isAriaInvalid as isAriaInvalid10 } from "@paalan/react-shared/lib";
import { forwardRef as forwardRef30 } from "@paalan/react-shared/utils";
import { Fragment as Fragment14, jsx as jsx37, jsxs as jsxs18 } from "react/jsx-runtime";
var BoxTextarea = Box.withComponent("textarea");
var Textarea = forwardRef30(
  ({
    className,
    isInvalid: invalid,
    label,
    inline,
    parentClassName,
    required,
    id,
    errorMessage,
    value,
    onValueChange,
    defaultValue,
    ...props
  }, ref) => {
    const [localValue, setLocalValue] = useState7(value ?? defaultValue);
    useEffect6(() => {
      setLocalValue(value);
    }, [value]);
    const isInvalid = isAriaInvalid10(props["aria-invalid"]) || invalid;
    const labelId = id || props.name || label;
    return /* @__PURE__ */ jsxs18(Fragment14, { children: [
      /* @__PURE__ */ jsxs18(
        Box,
        {
          className: cn34(
            "flex w-full flex-col gap-2",
            {
              "flex-row items-center": inline
            },
            parentClassName
          ),
          children: [
            label && /* @__PURE__ */ jsx37(
              Label,
              {
                htmlFor: labelId,
                required,
                className: cn34({
                  "text-danger": isInvalid
                }),
                children: label
              }
            ),
            /* @__PURE__ */ jsx37(
              BoxTextarea,
              {
                ...props,
                className: cn34(
                  "flex min-h-[60px] w-full rounded-md border border-input bg-transparent px-3 py-2 text-sm shadow-sm placeholder:text-muted-foreground focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring disabled:cursor-not-allowed disabled:opacity-50",
                  {
                    "border-danger placeholder:text-danger focus-visible:ring-danger/40": isInvalid,
                    "bg-muted/40 read-only:focus-visible:ring-0": props.readOnly
                  },
                  className
                ),
                ref,
                id: labelId,
                required,
                value: localValue,
                onChange: (e) => {
                  onValueChange?.(e.target.value);
                  props.onChange?.(e);
                }
              }
            )
          ]
        }
      ),
      isInvalid && /* @__PURE__ */ jsx37(ErrorMessage, { message: errorMessage })
    ] });
  }
);
Textarea.displayName = "Textarea";

// src/components/Form/FormFieldItem/index.tsx
import { Fragment as Fragment15, jsx as jsx38, jsxs as jsxs19 } from "react/jsx-runtime";
var FormFieldItemComponent = ({
  inline: formInline,
  control,
  field
}) => {
  const { required, label, labelDescription, inline, formItemClassName, formLabelClassName, ...item } = field;
  const inlineTypes = ["checkbox"];
  return /* @__PURE__ */ jsx38(
    FormField,
    {
      control,
      name: item.name,
      render: ({ field: field2 }) => /* @__PURE__ */ jsxs19(FormItem, { className: formItemClassName, children: [
        /* @__PURE__ */ jsxs19(
          "div",
          {
            className: cn35("flex flex-col gap-2", {
              "flex-row items-center": inline || formInline || inlineTypes.includes(item.type)
            }),
            children: [
              label && /* @__PURE__ */ jsx38(
                FormLabel,
                {
                  required,
                  htmlFor: field2.name,
                  className: cn35(
                    {
                      "break-word w-[9rem] shrink-0": formInline && !inlineTypes.includes(item.type),
                      "order-1": inlineTypes.includes(item.type)
                    },
                    formLabelClassName
                  ),
                  labelDescription,
                  children: label
                }
              ),
              /* @__PURE__ */ jsxs19(Fragment15, { children: [
                item.type === "custom" && /* @__PURE__ */ jsx38(FormControl, { children: item.render?.({ field: field2 }) }),
                item.type === "input" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  Input,
                  {
                    ...field2,
                    id: field2.name,
                    autoComplete: item.autoComplete,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    type: item.inputType || "text",
                    ...item?.inputProps,
                    inputType: void 0,
                    onChange: (event) => {
                      field2.onChange(event.currentTarget.value);
                      item.onValueChange?.(event.currentTarget.value);
                      item.onChange?.(event);
                    }
                  }
                ) }),
                item.type === "number" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  NumberInput,
                  {
                    ...field2,
                    id: field2.name,
                    value: field2.value ?? "",
                    autoComplete: item.autoComplete,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    ...item?.numberInputProps,
                    onChange: (event) => {
                      const value = event.currentTarget.valueAsNumber;
                      field2.onChange(Number.isNaN(value) ? void 0 : value);
                      item.onValueChange?.(value);
                    }
                  }
                ) }),
                item.type === "textarea" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  Textarea,
                  {
                    ...field2,
                    id: field2.name,
                    autoComplete: item.autoComplete,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    ...item?.textareaProps,
                    onChange: (event) => {
                      field2.onChange(event.currentTarget.value);
                      item.onValueChange?.(event.currentTarget.value);
                      item.onChange?.(event);
                    }
                  }
                ) }),
                item.type === "select" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  Select,
                  {
                    ...field2,
                    id: field2.name,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    triggerClassName: item.triggerClassName,
                    contentClassName: item.contentClassName,
                    options: item.options,
                    ...item?.selectProps,
                    onValueChange: (value) => {
                      field2.onChange(value || void 0);
                      item.onValueChange?.(value);
                    }
                  }
                ) }),
                item.type === "checkbox" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  Checkbox,
                  {
                    ...field2,
                    id: field2.name,
                    disabled: item.disabled,
                    className: item.className,
                    variant: item.variant,
                    type: "button",
                    ...item?.checkboxProps,
                    onChange: item?.onChange,
                    onCheckedChange: (checked) => {
                      field2.onChange(checked);
                      item.onCheckedChange?.(checked);
                    }
                  }
                ) }),
                item.type === "checkbox-group" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  CheckboxGroup,
                  {
                    ...field2,
                    inline: item.checkboxInline,
                    className: item.className,
                    options: item.options,
                    labelClassName: item.labelClassName,
                    swapRight: item.swapRight,
                    variant: item.variant,
                    ...item?.checkboxGroupProps,
                    selectedValues: field2.value?.length ? field2.value : void 0,
                    onSelectedValueChange: (values) => {
                      field2.onChange(values.length ? values : void 0);
                      item.onSelectedValueChange?.(values);
                    }
                  }
                ) }),
                item.type === "radio-group" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  RadioGroup,
                  {
                    ...field2,
                    id: field2.name,
                    inline: item.radioInline,
                    className: item.className,
                    options: item.options,
                    labelClassName: item.labelClassName,
                    swapRight: item.swapRight,
                    variant: item.variant,
                    disabled: item.disabled,
                    ...item?.radioGroupProps,
                    onChange: item?.onChange,
                    onValueChange: (value) => {
                      field2.onChange(value || void 0);
                      item.onValueChange?.(value);
                    }
                  }
                ) }),
                item.type === "combobox" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  Combobox,
                  {
                    ...field2,
                    options: item.options,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    ...item?.comboboxProps,
                    onValueChange: (value) => {
                      field2.onChange(value || void 0);
                      item.onValueChange?.(value);
                    }
                  }
                ) }),
                item.type === "multi-select" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  MultiSelect,
                  {
                    ...field2,
                    options: item.options,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    triggerClassName: item.triggerClassName,
                    contentClassName: item.contentClassName,
                    commandClassName: item.commandClassName,
                    ...item?.multiSelectProps,
                    selectedValues: field2.value?.length ? field2.value : void 0,
                    onSelectedValueChange: (values) => {
                      field2.onChange(values.length ? values : void 0);
                      item.onSelectedValueChange?.(values);
                    }
                  }
                ) }),
                item.type === "date-picker" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  DatePicker,
                  {
                    ...field2,
                    date: field2.value,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    ...item?.datePickerProps,
                    onDateChange: (value) => {
                      field2.onChange(value || void 0);
                      item.onDateChange?.(value);
                    }
                  }
                ) }),
                item.type === "date-range-picker" && /* @__PURE__ */ jsx38(FormControl, { children: /* @__PURE__ */ jsx38(
                  DateRangePicker,
                  {
                    ...field2,
                    dateRange: field2.value,
                    placeholder: item.placeholder,
                    disabled: item.disabled,
                    className: item.className,
                    ...item?.dateRangePickerProps,
                    onDateRangeChange: (value) => {
                      field2.onChange(value || void 0);
                      item.onDateRangeChange?.(value);
                    }
                  }
                ) })
              ] })
            ]
          }
        ),
        item.description && /* @__PURE__ */ jsx38(
          FormDescription,
          {
            className: cn35({
              "pl-[9.5rem]": formInline
            }),
            children: item.description
          }
        ),
        /* @__PURE__ */ jsx38(
          FormMessage,
          {
            className: cn35({
              "pl-[9.5rem]": formInline
            })
          }
        )
      ] })
    }
  );
};

// src/components/Form/FormFieldItems/index.tsx
import { Fragment as Fragment16, jsx as jsx39 } from "react/jsx-runtime";
var FormFieldItems = ({ fields, ...props }) => {
  return /* @__PURE__ */ jsx39(Fragment16, { children: fields.map((field) => /* @__PURE__ */ jsx39(FormFieldItemComponent, { field, ...props }, field.name)) });
};

// src/components/Form/Form.tsx
import { jsx as jsx40, jsxs as jsxs20 } from "react/jsx-runtime";
var Form = ({
  form,
  onSubmit,
  onSubmitError,
  fields,
  className,
  submitText = "Submit",
  SubmitButton,
  submitButtonVariant = "solid",
  submitButtonColor = "primary",
  submitClassName,
  resetText = "Reset",
  ResetButton,
  resetButtonVariant = "outline",
  resetButtonColor,
  resetClassName,
  actionClassName,
  hideResetButton = false,
  hideSubmitButton = false,
  noValidate = true,
  inline: formInline,
  formRef,
  id,
  isSubmitting: isFormSubmitting,
  isResetting,
  onReset,
  children
}) => {
  const isSubmitting = isFormSubmitting ?? form.formState.isSubmitting;
  const isActionSectionVisible = !hideResetButton || !hideSubmitButton || !!ResetButton || !!SubmitButton;
  return /* @__PURE__ */ jsx40(FormRoot, { ...form, children: /* @__PURE__ */ jsxs20(
    "form",
    {
      id,
      ref: formRef,
      noValidate,
      onSubmit: onSubmit ? form.handleSubmit(onSubmit, onSubmitError) : void 0,
      className: cn36("space-y-4", className),
      children: [
        /* @__PURE__ */ jsx40(FormFieldItems, { fields, inline: formInline, control: form.control }),
        children,
        isActionSectionVisible && /* @__PURE__ */ jsxs20(Box, { className: cn36("flex gap-3", actionClassName), children: [
          ResetButton ? /* @__PURE__ */ jsx40(ResetButton, { onFormReset: form.reset }) : !hideResetButton && /* @__PURE__ */ jsx40(
            Button,
            {
              type: "reset",
              variant: resetButtonVariant,
              color: resetButtonColor,
              disabled: isResetting,
              onClick: () => {
                form.reset();
                onReset?.();
              },
              className: resetClassName,
              children: resetText
            }
          ),
          SubmitButton ? /* @__PURE__ */ jsx40(
            SubmitButton,
            {
              isSubmitting,
              onFormSubmit: onSubmit ? form.handleSubmit(onSubmit, onSubmitError) : void 0
            }
          ) : !hideSubmitButton && /* @__PURE__ */ jsx40(
            Button,
            {
              type: "submit",
              variant: submitButtonVariant,
              color: submitButtonColor,
              isLoading: isSubmitting,
              className: submitClassName,
              children: submitText
            }
          )
        ] })
      ]
    }
  ) });
};
Form.displayName = "Form";
export {
  Form
};
