'use client';

// src/components/Menubar/Menubar.tsx
import * as React from "react";
import { CheckIcon, ChevronRightIcon, DotFilledIcon } from "@paalan/react-icons";
import { cn } from "@paalan/react-shared/lib";
import * as MenubarPrimitive from "@radix-ui/react-menubar";

// src/components/Menubar/helper.ts
var isMenubarMenuSeparator = (menu) => {
  return "separator" in menu;
};
var isMenubarMenuCheckbox = (menu) => {
  return menu.type === "checkbox";
};
var isMenubarMenuRadio = (menu) => {
  return menu.type === "radio";
};

// src/components/Menubar/Menubar.tsx
import { jsx, jsxs } from "react/jsx-runtime";
var MenubarMenu = MenubarPrimitive.Menu;
var MenubarGroup = MenubarPrimitive.Group;
var MenubarPortal = MenubarPrimitive.Portal;
var MenubarSub = MenubarPrimitive.Sub;
var MenubarRadioGroup = MenubarPrimitive.RadioGroup;
var MenubarRoot = React.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx(
  MenubarPrimitive.Root,
  {
    ref,
    className: cn("flex h-9 items-center space-x-1 rounded-md border bg-background p-1 shadow-sm", className),
    ...props
  }
));
MenubarRoot.displayName = MenubarPrimitive.Root.displayName;
var MenubarTrigger = React.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx(
  MenubarPrimitive.Trigger,
  {
    ref,
    className: cn(
      "flex cursor-default select-none items-center rounded-sm px-3 py-1 text-sm font-medium outline-none focus:bg-accent focus:text-accent-foreground data-[state=open]:bg-accent data-[state=open]:text-accent-foreground",
      className
    ),
    ...props
  }
));
MenubarTrigger.displayName = MenubarPrimitive.Trigger.displayName;
var MenubarSubTrigger = React.forwardRef(({ className, inset, children, ...props }, ref) => /* @__PURE__ */ jsxs(
  MenubarPrimitive.SubTrigger,
  {
    ref,
    className: cn(
      "flex cursor-default select-none items-center rounded-sm px-2 py-1.5 text-sm outline-none focus:bg-accent focus:text-accent-foreground data-[state=open]:bg-accent data-[state=open]:text-accent-foreground",
      inset && "pl-8",
      className
    ),
    ...props,
    children: [
      children,
      /* @__PURE__ */ jsx(ChevronRightIcon, { className: "ml-auto size-4" })
    ]
  }
));
MenubarSubTrigger.displayName = MenubarPrimitive.SubTrigger.displayName;
var MenubarSubContent = React.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx(
  MenubarPrimitive.SubContent,
  {
    ref,
    className: cn(
      "z-50 min-w-[8rem] overflow-hidden rounded-md border bg-popover p-1 text-popover-foreground shadow-lg data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      className
    ),
    ...props
  }
));
MenubarSubContent.displayName = MenubarPrimitive.SubContent.displayName;
var MenubarContent = React.forwardRef(({ className, align = "start", alignOffset = -4, sideOffset = 8, ...props }, ref) => /* @__PURE__ */ jsx(MenubarPrimitive.Portal, { children: /* @__PURE__ */ jsx(
  MenubarPrimitive.Content,
  {
    ref,
    align,
    alignOffset,
    sideOffset,
    className: cn(
      "z-50 min-w-[12rem] overflow-hidden rounded-md border bg-popover p-1 text-popover-foreground shadow-md data-[state=open]:animate-in data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2",
      className
    ),
    ...props
  }
) }));
MenubarContent.displayName = MenubarPrimitive.Content.displayName;
var MenubarItem = React.forwardRef(({ className, inset, ...props }, ref) => /* @__PURE__ */ jsx(
  MenubarPrimitive.Item,
  {
    ref,
    className: cn(
      "relative flex cursor-default select-none items-center rounded-sm px-2 py-1.5 text-sm outline-none focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",
      inset && "pl-8",
      className
    ),
    ...props
  }
));
MenubarItem.displayName = MenubarPrimitive.Item.displayName;
var MenubarCheckboxItem = React.forwardRef(({ className, children, checked, ...props }, ref) => /* @__PURE__ */ jsxs(
  MenubarPrimitive.CheckboxItem,
  {
    ref,
    className: cn(
      "relative flex cursor-default select-none items-center rounded-sm py-1.5 pl-8 pr-2 text-sm outline-none focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",
      className
    ),
    checked,
    ...props,
    children: [
      /* @__PURE__ */ jsx("span", { className: "absolute left-2 flex size-3.5 items-center justify-center", children: /* @__PURE__ */ jsx(MenubarPrimitive.ItemIndicator, { children: /* @__PURE__ */ jsx(CheckIcon, { className: "size-4" }) }) }),
      children
    ]
  }
));
MenubarCheckboxItem.displayName = MenubarPrimitive.CheckboxItem.displayName;
var MenubarRadioItem = React.forwardRef(({ className, children, ...props }, ref) => /* @__PURE__ */ jsxs(
  MenubarPrimitive.RadioItem,
  {
    ref,
    className: cn(
      "relative flex cursor-default select-none items-center rounded-sm py-1.5 pl-8 pr-2 text-sm outline-none focus:bg-accent focus:text-accent-foreground data-[disabled]:pointer-events-none data-[disabled]:opacity-50",
      className
    ),
    ...props,
    children: [
      /* @__PURE__ */ jsx("span", { className: "absolute left-2 flex size-3.5 items-center justify-center", children: /* @__PURE__ */ jsx(MenubarPrimitive.ItemIndicator, { children: /* @__PURE__ */ jsx(DotFilledIcon, { className: "size-4 fill-current" }) }) }),
      children
    ]
  }
));
MenubarRadioItem.displayName = MenubarPrimitive.RadioItem.displayName;
var MenubarLabel = React.forwardRef(({ className, inset, ...props }, ref) => /* @__PURE__ */ jsx(
  MenubarPrimitive.Label,
  {
    ref,
    className: cn("px-2 py-1.5 text-sm font-semibold", inset && "pl-8", className),
    ...props
  }
));
MenubarLabel.displayName = MenubarPrimitive.Label.displayName;
var MenubarSeparator = React.forwardRef(({ className, ...props }, ref) => /* @__PURE__ */ jsx(MenubarPrimitive.Separator, { ref, className: cn("-mx-1 my-1 h-px bg-muted", className), ...props }));
MenubarSeparator.displayName = MenubarPrimitive.Separator.displayName;
var MenubarShortcut = ({ className, ...props }) => {
  return /* @__PURE__ */ jsx("span", { className: cn("ml-auto text-xs tracking-widest text-muted-foreground", className), ...props });
};
MenubarShortcut.displayname = "MenubarShortcut";
var MenubarMenuCheckboxItem = ({ label, ...props }) => {
  return /* @__PURE__ */ jsx(MenubarCheckboxItem, { ...props, children: label });
};
var MenubarMenuRadioItem = ({ options, value, ...props }) => {
  return /* @__PURE__ */ jsx(MenubarRadioGroup, { value, children: options.map(({ label, value: value2 }) => /* @__PURE__ */ jsx(MenubarRadioItem, { value: value2, ...props, children: label }, value2)) });
};
var MenubarMenuItem = ({ label, shortcut, onClick, subMenus, ...props }) => {
  return /* @__PURE__ */ jsx(React.Fragment, { children: subMenus?.length ? subMenus.map(({ label: label2, items }, index) => /* @__PURE__ */ jsxs(MenubarSub, { children: [
    /* @__PURE__ */ jsx(MenubarSubTrigger, { children: label2 }),
    /* @__PURE__ */ jsx(MenubarSubContent, { children: items.map((item, index2) => /* @__PURE__ */ jsx(MenubarMenuItems, { ...item }, index2)) })
  ] }, index)) : /* @__PURE__ */ jsxs(MenubarItem, { onClick, ...props, children: [
    label,
    shortcut && /* @__PURE__ */ jsx(MenubarShortcut, { children: shortcut })
  ] }) });
};
MenubarMenuItem.displayName = "MenubarMenuItem";
var MenubarMenuItems = (props) => {
  if (isMenubarMenuSeparator(props)) {
    const { separator, ...restProps } = props;
    return /* @__PURE__ */ jsx(MenubarSeparator, { ...restProps });
  }
  if (isMenubarMenuCheckbox(props)) {
    return /* @__PURE__ */ jsx(MenubarMenuCheckboxItem, { ...props });
  }
  if (isMenubarMenuRadio(props)) {
    return /* @__PURE__ */ jsx(MenubarMenuRadioItem, { ...props });
  }
  return /* @__PURE__ */ jsx(MenubarMenuItem, { ...props });
};
var Menubar = React.forwardRef(({ menus, ...props }, ref) => /* @__PURE__ */ jsx(MenubarRoot, { ref, ...props, children: menus.map(({ label, items }, index) => /* @__PURE__ */ jsxs(MenubarMenu, { children: [
  /* @__PURE__ */ jsx(MenubarTrigger, { children: label }),
  /* @__PURE__ */ jsx(MenubarContent, { children: items.map((item, index2) => /* @__PURE__ */ jsx(MenubarMenuItems, { ...item }, index2)) })
] }, index)) }));
Menubar.displayName = "Menubar";
export {
  Menubar,
  MenubarCheckboxItem,
  MenubarContent,
  MenubarGroup,
  MenubarItem,
  MenubarLabel,
  MenubarMenu,
  MenubarMenuCheckboxItem,
  MenubarMenuItem,
  MenubarMenuItems,
  MenubarMenuRadioItem,
  MenubarPortal,
  MenubarRadioGroup,
  MenubarRadioItem,
  MenubarRoot,
  MenubarSeparator,
  MenubarShortcut,
  MenubarSub,
  MenubarSubContent,
  MenubarSubTrigger,
  MenubarTrigger,
  isMenubarMenuCheckbox,
  isMenubarMenuRadio,
  isMenubarMenuSeparator
};
